@@ -14,17 +14,26 @@ fi
 # Build debian package..
 PACKAGE=`head -n 1 debian/control | cut -f2 -d' '`
 PACKAGE_DOC=${PACKAGE}-doc
-USER=${1:-"`grep -e \"Maintainer:\" debian/control|cut -d\":\" -f2`"}
+USER=${1:-"${DEBFULLNAME} <${DEBEMAIL}>"}
+if [ "$USER" = "" -o "$USER" = " " ] ; then
+  USER="`grep -e \"Maintainer:\" debian/control|cut -d\":\" -f2`"
+fi
 VERSION=`head -n 1 debian/changelog | cut -f2 -d\( | cut -f1 -d')' | cut -f1 -d-`
 
 # CVS repositories..
 HTMLAREA_CVSROOT=":pserver:anonymous@cvs.sourceforge.net:/cvsroot/itools-htmlarea"
 PACKAGE_CVSROOT=catalyst/codeforge/php/${PACKAGE}
 
-echo -n "refresh ChangeLog? (y/n) [n]: "
-read ANS
+# If not present, always build ChangeLog, else ask..
+if [ ! -f ChangeLog ]; then
+  ANS=y
+else
+  echo -n "refresh ChangeLog? (y/n) [n]: "
+  read ANS
+fi
 if [ "$ANS" = "y" -o "$ANS" = "Y" ]
 then
+  echo "generating ChangeLog.."
   cvs2cl >/dev/null 2>&1
 fi
 
