@@ -78,6 +78,10 @@ echo " connecting as: $DBUSER"
 [ "$DBHOST" != "direct" ] && echo " port: $DBPORT"
 echo ""
 
+# Optional host settings for remotely accessed databases..
+HOSTOPTS=""
+[ "$DBHOST" != "direct" ] && HOSTOPTS="--host $DBHOST --port $DBPORT"
+
 # We require Postgres to be locally installed, at least as postgresql-client
 # even if no servers are created locally. This is based on the standard
 # Debian location, with a few likely fallbacks..
@@ -195,7 +199,7 @@ then
   fi
 
   # Get database version..
-  pg_version="`su postgres -c \"psql template1 -qAtc 'select version()'\" | cut -f2 -d' '`"
+  pg_version="`su postgres -p -c \"psql template1 -qAtc 'select version()'\" | cut -f2 -d' '`"
   echo "postgres version is $pg_version"
 
   # User should have an account on the machine too..
@@ -215,7 +219,7 @@ then
   tmp2=$(mktemp /tmp/$pattern)
   if [ $PG_OLDVER = "yes" ]
   then
-    if su -s /bin/sh postgres -c "createuser --createdb --no-adduser $DBUSER" 1> $tmp1 2> $tmp2 \
+    if su postgres -p -c "createuser --createdb --no-adduser $DBUSER" 1> $tmp1 2> $tmp2 \
       && [ "$(head -1 $tmp1)" = 'CREATE USER' ] \
       || grep -q "user name \"$DBUSER\" already exists$" $tmp2
     then
@@ -235,7 +239,7 @@ then
       exit 1
     fi
   else
-    if su -s /bin/sh postgres -c "/usr/bin/psql template1" &> /dev/null <<-EOF
+    if su postgres -p -c "/usr/bin/psql template1" &> /dev/null <<-EOF
 CREATE USER $DBUSER WITH PASSWORD '$DBPASSWD' CREATEDB;
 EOF
     then
@@ -258,7 +262,7 @@ EOF
   # Create the appropriate database
   tmp1=$(mktemp /tmp/$pattern)
   tmp2=$(mktemp /tmp/$pattern)
-  if su -s /bin/sh postgres -c "createdb --username ${DBUSER} --encoding UTF-8 ${DBNAME}" 1> $tmp1 2> $tmp2 \
+  if su postgres -p -c "createdb --username ${DBUSER} --encoding UTF-8 ${DBNAME}" 1> $tmp1 2> $tmp2 \
     && [ "$(head -1 $tmp1)" = 'CREATE DATABASE' ]
   then
     # Creation OK..
@@ -297,7 +301,7 @@ EOF
   fi
   if [ -x $PG_LANG ]
   then
-    if su -s /bin/sh postgres -c "${PG_LANG} plpgsql ${DBNAME}" 1> $tmp1 2> $tmp2 \
+    if su postgres -p -c "${PG_LANG} plpgsql ${DBNAME}" 1> $tmp1 2> $tmp2 \
       || grep -q "plpgsql added to $DBNAME" $tmp1 \
       || grep -q "plpgsql is already enabled in $DBNAME" $tmp1
     then
@@ -394,56 +398,31 @@ then
   esac
 
   # Now load the database, either direct or remotely..
-  if [ "$DBHOST" = "direct" ]
-  then
-    case "$INSTALLTYPE" in
-      empty)
-        # Load core schema and then core data..
-        $PSQL --username $DBUSER --dbname $DBNAME --file $DBSCHEMA
-        $PSQL --username $DBUSER --dbname $DBNAME --file $DBTRIG
-        $PSQL --username $DBUSER --dbname $DBNAME --file $DBTEMP
-        if [ "$META" = "y" ]
-        then
-          $PSQL --username $DBUSER --dbname $DBNAME --file $DBMETADATA
-        fi
-        if [ "$MICRO" = "y" ]
-        then
-          $PSQL --username $DBUSER --dbname $DBNAME --file $DBMICRODATA
-        fi
-        # Insert the Axyl control record..
-        $PSQL --username $DBUSER --dbname $DBNAME --command "INSERT INTO ax_control (site_axyl_version,app_prefix,site_docroot) VALUES ('${AXVER}','${APFX}','${DOCROOT}')"
-        ;;
-      demo)
-        # For the demo, we load a complete database dump which
-        # includes the schema and data..
-        $PSQL --username $DBUSER --dbname $DBNAME --file $DBTEMP
-        ;;
-    esac
-  else
-    case "$INSTALLTYPE" in
-      empty)
-        # Load core schema and then core data..
-        $PSQL --username $DBUSER --dbname $DBNAME --host $DBHOST --port $DBPORT --file $DBSCHEMA
-        $PSQL --username $DBUSER --dbname $DBNAME --host $DBHOST --port $DBPORT --file $DBTRIG
-        $PSQL --username $DBUSER --dbname $DBNAME --host $DBHOST --port $DBPORT --file $DBTEMP
-        if [ "$META" = "y" ]
-        then
-          $PSQL --username $DBUSER --dbname $DBNAME --host $DBHOST --port $DBPORT --file $DBMETADATA
-        fi
-        if [ "$MICRO" = "y" ]
-        then
-          $PSQL --username $DBUSER --dbname $DBNAME --host $DBHOST --port $DBPORT --file $DBMICRODATA
-        fi
-        # Insert the Axyl control record..
-        $PSQL --username $DBUSER --dbname $DBNAME --host $DBHOST --port $DBPORT --command "INSERT INTO ax_control (site_axyl_version,app_prefix,site_docroot) VALUES ('${AXVER}','${APFX}','${DOCROOT}')"
-        ;;
-      demo)
-        # For the demo, we load a complete database dump which
-        # includes the schema and data..
-        $PSQL --username $DBUSER --dbname $DBNAME --host $DBHOST --port $DBPORT --file $DBTEMP
-        ;;
-    esac
-  fi
+  case "$INSTALLTYPE" in
+    empty)
+      # Load core schema and then core data..
+      $PSQL --username $DBUSER --dbname $DBNAME $HOSTOPTS --file $DBSCHEMA
+      $PSQL --username $DBUSER --dbname $DBNAME $HOSTOPTS --file $DBTRIG
+      $PSQL --username $DBUSER --dbname $DBNAME $HOSTOPTS --file $DBTEMP
+      if [ "$META" = "y" ]
+      then
+        $PSQL --username $DBUSER --dbname $DBNAME $HOSTOPTS --file $DBMETADATA
+      fi
+      if [ "$MICRO" = "y" ]
+      then
+        $PSQL --username $DBUSER --dbname $DBNAME $HOSTOPTS --file $DBMICRODATA
+      fi
+      # Insert the Axyl control record..
+      $PSQL --username $DBUSER --dbname $DBNAME $HOSTOPTS --command "INSERT INTO ax_control (site_axyl_version,app_prefix,site_docroot) VALUES ('${AXVER}','${APFX}','${DOCROOT}')"
+      ;;
+    demo)
+      # For the demo, we load a complete database dump which
+      # includes the schema and data..
+      $PSQL --username $DBUSER --dbname $DBNAME $HOSTOPTS --file $DBTEMP
+      # Update the Axyl control record..
+      $PSQL --username $DBUSER --dbname $DBNAME $HOSTOPTS --command "UPDATE ax_control SET site_axyl_version='${AXVER}',app_prefix='${APFX}',site_docroot='${DOCROOT}'"
+      ;;
+  esac
   #rm -f $DBTEMP
   echo "finished"
 else
