@@ -20,7 +20,7 @@
 /*   Boston, MA  02111-1307  USA                                        */
 /* -------------------------------------------------------------------- */
 /*                                                                      */
-/* Filename:    /var/cm/axyl-tour-12.4.php                                         */
+/* Filename:    /var/cm/axyl-tour-4.1.php                                         */
 /* Author:      Paul Waite                                              */
 /* Description: Php webpage with Content Management Layout.             */
 /*                                                                      */
@@ -36,8 +36,8 @@ include_once("layout-defs.php");
 // -----------------------------------------------------------------------
 // Content Managed Webpage
 // Set these as appropriate:
-$PAGE_TITLE = "Axyl Tour: Section 12.4 - Database Access";
-$LAYOUT_ID  = "79_Axyl_Tour:_Section_12.4_-_Database_Access";    // Must be unique
+$PAGE_TITLE = "Axyl Tour: Section 4.1 - Application Control";
+$LAYOUT_ID  = "59_Axyl_Tour:_Section_4.1_-_Application_Control";    // Must be unique
 $TEMPLATE   = "tour";
 
 // -----------------------------------------------------------------------
