@@ -27,17 +27,20 @@ fi
 # Parameters..
 if [ $# -lt 6 ]
 then
-  echo "usage: $THIS vhost servername admin_email documentroot axyl_home axyl_logs [silent]"
+  echo "usage: $THIS vhost servername admin_email documentroot maxmem maxupload [silent]"
   exit 3
 fi
+
 VHOST=$1
 VHOST=`echo $VHOST | sed -e "s;ASTERISK;*;g"`
 VSERVERNAME=$2
 ADMIN_EMAIL=$3
 DOCROOT=$4
-if [ "$5" != "" ]
+MAXMEM=$5
+MAXUPLOAD=$6
+if [ "$7" != "" ]
 then
-  MODE=$5
+  MODE=$7
 else
   MODE="interactive"
 fi
@@ -60,7 +63,7 @@ function fix_phpini () {
     CHKAX=`perl -n -e "m;${PATH_PATT};i && print;" ${PHP_INI}`
     if [ "$CHKAX" = "" ]
     then
-      if "$MODE" = "interactive" ]
+      if [ "$MODE" = "interactive" ]
       then
         echo "IMPORTANT:"
         echo "For Axyl Php scripts to work properly for $TITLE we need to make sure"
@@ -154,6 +157,13 @@ then
   echo "  ErrorLog ${APACHE_LOGS}/${VSERVERNAME}-error.log" >>${CONF_NEW}
   echo "  CustomLog ${APACHE_LOGS}/${VSERVERNAME}-access.log common" >>${CONF_NEW}
   echo "  php_value include_path \".:${DOCROOT}:${AXYL_HOME}/lib\"" >>${CONF_NEW}
+  echo "  php_flag register_globals on" >>${CONF_NEW}
+  echo "  php_flag display_errors off" >>${CONF_NEW}
+  echo "  php_flag log_errors on" >>${CONF_NEW}
+  echo "  php_flag magic_quotes_gpc off" >>${CONF_NEW}
+  echo "  php_value memory_limit ${MAXMEM}M" >>${CONF_NEW}
+  echo "  php_value upload_max_filesize ${MAXUPLOAD}M" >>${CONF_NEW}
+  echo "  php_value post_max_size ${MAXUPLOAD}M" >>${CONF_NEW}
   echo "  <Directory ${DOCROOT}/>" >>${CONF_NEW}
   echo "    Order Deny,Allow" >>${CONF_NEW}
   echo "    Allow from All" >>${CONF_NEW}
@@ -204,7 +214,7 @@ PHP_INI_ETC_OLD=${PHP_INI_ETC}.axyl-saved.${TSTAMP}
 #fix_phpini "Apache" $AXYL_HOME $PHP_INI_APACHE $PHP_INI_APACHE_OLD
 #fix_phpini "All" $AXYL_HOME $PHP_INI_ETC $PHP_INI_ETC_OLD
 
-tell "checking php.ini settings.."
+tell "checking your CLI/CGI script php.ini settings.."
 fix_phpini "CGI" $AXYL_HOME $PHP_INI_CGI $PHP_INI_CGI_OLD
 fix_phpini "CLI" $AXYL_HOME $PHP_INI_CLI $PHP_INI_CLI_OLD
 
