@@ -439,6 +439,18 @@ then
   echo -n "Enter the document root [${DOCROOT}] :"
   read ANS
   [ "$ANS" != "" ] && DOCROOT=$ANS
+
+  # Memory limit
+  MAXMEM=32
+  echo -n "Maximum memory (in Mb) that PHP should use [${MAXMEM}] :"
+  read ANS
+  [ "$ANS" != "" ] && MAXMEM=$ANS
+
+  # Max upload filesize
+  MAXUPLOAD=5
+  echo -n "Maximum size of an uploaded file (in Mb) [${MAXUPLOAD}] :"
+  read ANS
+  [ "$ANS" != "" ] && MAXUPLOAD=$ANS
 else
   CONFIG_APACHE=no
   VHOST=none
@@ -505,7 +517,7 @@ echo ""
 if [ "$CONFIG_APACHE" = "yes" ]
 then
   echo "Configuring Apache"
-  ${AXYL_HOME}/install/config-apache.sh $VHOST $VSERVERNAME $ADMIN_EMAIL $DOCROOT $AXYL_HOME $AXYL_LOGS
+  ${AXYL_HOME}/install/config-apache.sh $VHOST $VSERVERNAME $ADMIN_EMAIL $DOCROOT $MAXMEM $MAXUPLOAD
 fi
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -571,4 +583,4 @@ echo "kept as non-writeable to the web-server."
 echo ""
 echo "The Axyl Team"
 
-# END
+# END
\ No newline at end of file
