@@ -37,8 +37,7 @@ fi
 # Acquire the local configuration..
 CONFDIR=/etc/axyl
 CONF=${CONFDIR}/axyl.conf
-if [ ! -f $CONF ]
-then
+if [ ! -f $CONF ] ; then
   echo "Axyl configuration file $CONF not found!"
   exit 2
 else
@@ -56,14 +55,11 @@ WWWUSER=www-data
 WWWGROUP=$WWWUSER
 
 # Deal with passed-in parameters..
-if [ "$1" != "" ]
-then
+if [ "$1" != "" ] ; then
   WWWADMIN=$1
-  if [ "$2" != "" ]
-  then
+  if [ "$2" != "" ] ; then
     WWWUSER=$2
-    if [ "$3" != "" ]
-    then
+    if [ "$3" != "" ] ; then
       WWWGROUP=$3
     else
       WWWGROUP=$WWWUSER
@@ -71,8 +67,7 @@ then
   fi
 else
   # Try to ascertain the settings from Apache config..
-  if [ -r ${APACHE_CONFDIR}/httpd.conf ]
-  then
+  if [ -r ${APACHE_CONFDIR}/httpd.conf ] ; then
     G=`grep "^Group " ${APACHE_CONFDIR}/httpd.conf | cut -d" " -f2`
     U=`grep "^User " ${APACHE_CONFDIR}/httpd.conf | cut -d" " -f2`
     [ "$G" != "" ] && WWWGROUP=$G
@@ -88,19 +83,19 @@ chown -R ${AXUSER}:${WWWADMIN} .
 chmod -R 0664 .
 chmod -R g+sw .
 find . -type d -exec chmod a+x {} \;
+
 # Executable Perl scripts..
 find . -type f -name "*.pl" -exec chmod ug+x {} \;
+
 # Php executables in the scripts directory..
-if [ -d scripts ]
-then
+if [ -d scripts ] ; then
   find scripts -type f -name "*.php" -exec chmod ug+x {} \;
 fi
+
 # Make all shell scripts executable..
 scripts=`find . -type f -exec grep -l -E -e "(\#\![[:space:]]*\/bin\/bash)|(\#\![[:space:]]*\/bin\/sh)" {} \;`
-if [ "$scripts" != "" ]
-then
-  for script in $scripts
-  do
+if [ "$scripts" != "" ] ; then
+  for script in $scripts ; do
     chmod ug+x $script
   done
 fi
@@ -110,4 +105,6 @@ chgrp -R ${WWWUSER} ./var
 
 echo "permissions have been set."
 
-exit 0
\ No newline at end of file
+exit 0
+
+# END
\ No newline at end of file
