@@ -114,7 +114,7 @@ mkgroup $WWWADMIN
 AXYL_DATA=/var/lib/axyl
 echo ""
 echo "Setting up the Axyl data area. This is where Lucene will store"
-echo "varying (growing) data such as Lucen indexes, so make sure you"
+echo "varying (growing) data such as Lucene indexes, so make sure you"
 echo "pick a location with that in mind."
 echo ""
 echo "Enter the full path of the Axyl data area.."
@@ -205,24 +205,25 @@ then
   # Read everything back..
   . $CONF
 
-  # Create version file if version is undefined..
-  if [ "$AXYL_VERSION" = "unknown" -o "$AXYL_VERSION" = "" ]
+  # Always re-write version file if we can establish version..
+  # (nb: some vars below are defined in axyl-common.sh)
+  CHGLOG=../debian/changelog
+  if [ -f $CHGLOG ]
   then
-    CHGLOG=../debian/changelog
-    if [ -f $CHGLOG ]
-    then
-      if [ "$VERSIONFILE" != "" ]
-      then
-        echo ""
-        echo "re-creating the Axyl version file.."
-        AXYL_VERSION=`head -n 1 $CHGLOG | cut -f2 -d\( | cut -f1 -d')' | cut -f1 -d-`
-        echo $AXYL_VERSION >$VERSIONFILE
-        echo "wrote $AXYL_VERSION to $VERSIONFILE"
+    echo ""
+    echo "re-writing the Axyl version file.."
+    NEW_AXYL_VERSION=`head -n 1 $CHGLOG | cut -f2 -d\( | cut -f1 -d')' | cut -f1 -d-`
+    echo $NEW_AXYL_VERSION >$VERSIONFILE
+    if [ "$AXYL_VERSION" != "$NEW_AXYL_VERSION" ] ; then
+      if [ "$AXYL_VERSION" = "" ] ; then
+        AXYL_VERSION=unset
       fi
-    else
-      echo "NOTE: check the Axyl version is present in $VERSIONFILE"
-      echo "it appears to be missing."
+      echo "Note: version is now $NEW_AXYL_VERSION (was $AXYL_VERSION)"
+      AXYL_VERSION=$NEW_AXYL_VERSION
     fi
+  else
+    echo "ERROR: could not locate Debian 'changelog' file. Are you running"
+    echo "this script from AXYL_HOME/install/ ?"
   fi
 
   # Assert proper ownership & perms..
@@ -230,6 +231,13 @@ then
   chmod -R 0644 $CONFDIR
   find $CONFDIR -type d -exec chmod 0775 {} \;
 
+  # Read the current version file..
+  AXYL_VERSION=`cat $VERSIONFILE`
+  if [ "$AXYL_VERSION" = "" ]
+  then
+    AXYL_VERSION="unknown"
+  fi
+
   echo ""
   echo "Configuration summary"
   echo " Axyl version: $AXYL_VERSION"
@@ -246,4 +254,4 @@ else
   echo "Axyl was NOT set up successfully."
 fi
 
-# END
\ No newline at end of file
+# END
