@@ -1506,182 +1506,186 @@ class blocklet extends RenderableObject {
     while ( preg_match($datapat, $content, $matches) ) {
       $datatag = $matches[0];
       $attributes = extractAttributes($datatag);
-      $new_content = "";
-      $type = strtolower($attributes["type"]);
-      if (count($attributes) > 0 && $type == "axyl/embedded-media") {
-        $mediatype = strtolower($attributes["codetype"]);
-        switch ($mediatype) {
-          // DATA
-          case "data":
-            $quid   = $attributes["id"];
-            $format = $attributes["format"];
-            $where  = $attributes["where"];
-            $tableheadings = (isset($attributes["tableheadings"]));
-            if ($quid != "") {
-              $qQ = dbrecordset("SELECT * FROM ax_query_resource WHERE quid=$quid");
-              if ($qQ->hasdata) {
-                // Datasource content..
-                if ($qQ->field("q_query") != "") {
-                  $datasrc = unserialize($qQ->field("q_query"));
-                  // Apply any block-level where clause..
-                  if ($where != "") {
-                    if ($datasrc->where->total > 0) {
-                      if (strtolower(substr($where, 0, 3)) != "and") {
-                        $where = "and $where";
+      if (!isset($attributes["name"])) {
+        $new_content = "";
+        $type = strtolower($attributes["type"]);
+        if (count($attributes) > 0 && $type == "axyl/embedded-media") {
+          $mediatype = strtolower($attributes["codetype"]);
+          switch ($mediatype) {
+            // DATA
+            case "data":
+              $quid   = $attributes["id"];
+              $format = $attributes["format"];
+              $where  = $attributes["where"];
+              $tableheadings = (isset($attributes["tableheadings"]));
+              if ($quid != "") {
+                $qQ = dbrecordset("SELECT * FROM ax_query_resource WHERE quid=$quid");
+                if ($qQ->hasdata) {
+                  // Datasource content..
+                  if ($qQ->field("q_query") != "") {
+                    $datasrc = unserialize($qQ->field("q_query"));
+                    // Apply any block-level where clause..
+                    if ($where != "") {
+                      if ($datasrc->where->total > 0) {
+                        if (strtolower(substr($where, 0, 3)) != "and") {
+                          $where = "and $where";
+                        }
                       }
+                      $datasrc->where($where);
                     }
-                    $datasrc->where($where);
-                  }
-                  $raw_content = "";
-                  // Handle table headings if required..
-                  if ($format == "table" && $tableheadings) {
-                    $fieldnames = explode(",", $datasrc->fields->listed());
-                    $headings = array();
-                    foreach ($fieldnames as $fieldname) {
-                      if (strstr($fieldname, ".")) {
-                        $bits = explode(".", $fieldname);
-                        $fieldname = $bits[1];
+                    $raw_content = "";
+                    // Handle table headings if required..
+                    if ($format == "table" && $tableheadings) {
+                      $fieldnames = explode(",", $datasrc->fields->listed());
+                      $headings = array();
+                      foreach ($fieldnames as $fieldname) {
+                        if (strstr($fieldname, ".")) {
+                          $bits = explode(".", $fieldname);
+                          $fieldname = $bits[1];
+                        }
+                        $headings[] = ucfirst(str_replace("_", " ", $fieldname));
                       }
-                      $headings[] = ucfirst(str_replace("_", " ", $fieldname));
+                      $raw_content .= implode("^", $headings) . "\n";
+                    }
+                    // Get datasource data..
+                    $datasrc->execute();
+                    if ($datasrc->hasdata) {
+                      do {
+                        $data = array();
+                        for ($i=0; $i < $datasrc->fields->total; $i++) {
+                          $data[] = $datasrc->current_row[$i];
+                        }
+                        switch ($format) {
+                          case "list":
+                          case "ordered":
+                          case "bullets":
+                            $raw_content .= implode(" ", $data) . "\n";
+                            break;
+                          case "table":
+                            $raw_content .= implode("|", $data) . "\n";
+                            break;
+                          default:
+                            $raw_content .= implode(" ", $data);
+                        } // switch
+                      } while ($datasrc->get_next());
+                      $new_content = $this->format_content(
+                                      $raw_content,
+                                      $format,
+                                      $this->content_css()
+                                      );
                     }
-                    $raw_content .= implode("^", $headings) . "\n";
                   }
-                  // Get datasource data..
-                  $datasrc->execute();
-                  if ($datasrc->hasdata) {
-                    do {
-                      $data = array();
-                      for ($i=0; $i < $datasrc->fields->total; $i++) {
-                        $data[] = $datasrc->current_row[$i];
-                      }
-                      switch ($format) {
-                        case "list":
-                        case "ordered":
-                        case "bullets":
-                          $raw_content .= implode(" ", $data) . "\n";
-                          break;
-                        case "table":
-                          $raw_content .= implode("|", $data) . "\n";
-                          break;
-                        default:
-                          $raw_content .= implode(" ", $data);
-                      } // switch
-                    } while ($datasrc->get_next());
-                    $new_content = $this->format_content(
-                                    $raw_content,
-                                    $format,
-                                    $this->content_css()
-                                    );
+                  // Script-generated content..
+                  elseif ($qQ->field("q_script") != "") {
+                    debugbr("execute script here.", DBG_DEBUG);
                   }
                 }
-                // Script-generated content..
-                elseif ($qQ->field("q_script") != "") {
-                  debugbr("execute script here.", DBG_DEBUG);
+              }
+              // case data
+              break;
+  
+            // IMAGE
+            case "image":
+              $catid   = $attributes["id"];
+              $align   = $attributes["align"];
+              $pad     = $attributes["pad"];
+              $tooltip = $attributes["title"];
+              $width   = $attributes["width"];
+              $height  = $attributes["height"];
+              $border  = $attributes["border"];
+              $bdcolor = $attributes["bordercolor"];
+              if ($catid != "") {
+                $qQ = dbrecordset("SELECT * FROM ax_catalog WHERE cat_id=$catid");
+                if ($qQ->hasdata) {
+                  $src = $qQ->field("filepath");
+                  if ($width == 0 || $width == "") $width = $qQ->field("width");
+                  if ($width == 0 || $width == "") $width = false;
+                  if ($height == 0 || $height == "") $height = $qQ->field("height");
+                  if ($height == 0 || $height == "") $height = false;
+                  $img=new img($src, $catid, $tooltip, $width, $height);
+                  if ($border != "") {
+                    $img->setborder($border);
+                    $img->setstyle("border-style:solid;border-width:" . $border . "px;");
+                    if ($bdcolor != "") $img->setstyle("border-color:$bdcolor;");
+                  }
+                  if ($align != "") $img->setalign($align);
+                  if ($pad != "") {
+                    $img->sethspace($pad);
+                    $img->setvspace($pad);
+                  }
+                  $new_content = $img->render();
                 }
               }
-            }
-            // case data
-            break;
-
-          // IMAGE
-          case "image":
-            $catid   = $attributes["id"];
-            $align   = $attributes["align"];
-            $pad     = $attributes["pad"];
-            $tooltip = $attributes["title"];
-            $width   = $attributes["width"];
-            $height  = $attributes["height"];
-            $border  = $attributes["border"];
-            $bdcolor = $attributes["bordercolor"];
-            if ($catid != "") {
-              $qQ = dbrecordset("SELECT * FROM ax_catalog WHERE cat_id=$catid");
-              if ($qQ->hasdata) {
-                $src = $qQ->field("filepath");
-                if ($width == 0 || $width == "") $width = $qQ->field("width");
-                if ($width == 0 || $width == "") $width = false;
-                if ($height == 0 || $height == "") $height = $qQ->field("height");
-                if ($height == 0 || $height == "") $height = false;
-                $img=new img($src, $catid, $tooltip, $width, $height);
-                if ($border != "") {
-                  $img->setborder($border);
-                  $img->setstyle("border-style:solid;border-width:" . $border . "px;");
-                  if ($bdcolor != "") $img->setstyle("border-color:$bdcolor;");
-                }
-                if ($align != "") $img->setalign($align);
-                if ($pad != "") {
-                  $img->sethspace($pad);
-                  $img->setvspace($pad);
-                }
-                $new_content = $img->render();
+              break;
+  
+            // MEDIA or DOCUMENT
+            case "media":
+            case "document":
+              $new_content = "";
+              $catid   = $attributes["id"];
+              $display = $attributes["display"];
+              $width   = $attributes["width"];
+              $height  = $attributes["height"];
+              if ($mediatype == "media") {
+                $autostart    = ($attributes["autostart"] == "yes");
+                $loop         = ($attributes["loop"] == "yes");
+                $showcontrols = ($attributes["showcontrols"] == "yes");
               }
-            }
-            break;
-
-          // MEDIA or DOCUMENT
-          case "media":
-          case "document":
-            $new_content = "";
-            $catid   = $attributes["id"];
-            $display = $attributes["display"];
-            $width   = $attributes["width"];
-            $height  = $attributes["height"];
-            if ($mediatype == "media") {
-              $autostart    = ($attributes["autostart"] == "yes");
-              $loop         = ($attributes["loop"] == "yes");
-              $showcontrols = ($attributes["showcontrols"] == "yes");
-            }
-            if ($width  == 0 || $width  == "") $width = 200;
-            if ($height == 0 || $height == "") $height = 200;
-            $tooltip = $attributes["title"];
-            if ($catid != "") {
-              $qQ = dbrecordset("SELECT * FROM ax_catalog WHERE cat_id=$catid");
-              if ($qQ->hasdata) {
-                $src = $qQ->field("filepath");
-                $category = $qQ->field("mime_category");
-                switch ($category) {
-                  case "movie":
-                    $media = new MediaObject($src, $width, $height, $autostart, $loop, $showcontrols);
-                    switch ($display) {
-                      case "icon": $media->AsIcon($tooltip); break;
-                      case "link": $media->AsLink($tooltip); break;
-                    }
-                    break;
-                  case "audio":
-                    $media = new MediaObject($src, $width, $height, $autostart, $loop, $showcontrols);
-                    switch ($display) {
-                      case "icon": $media->AsIcon($tooltip); break;
-                      case "link": $media->AsLink($tooltip); break;
-                    }
-                    break;
-                  case "flash":
-                    $media = new FlashObject($src, $width, $height, $autostart, $loop);
-                    switch ($display) {
-                      case "icon": $media->AsIcon($tooltip); break;
-                      case "link": $media->AsLink($tooltip); break;
-                    }
-                    break;
-                  case "document":
-                    $media = new DocumentObject($src, $width, $height);
-                    switch ($display) {
-                      case "icon": $media->AsIcon($tooltip); break;
-                      case "link": $media->AsLink($tooltip, "_new"); break;
-                    }
-                    break;
-                } // switch
-                if (is_object($media)) {
-                  $new_content = $media->render();
+              if ($width  == 0 || $width  == "") $width = 200;
+              if ($height == 0 || $height == "") $height = 200;
+              $tooltip = $attributes["title"];
+              if ($catid != "") {
+                $qQ = dbrecordset("SELECT * FROM ax_catalog WHERE cat_id=$catid");
+                if ($qQ->hasdata) {
+                  $src = $qQ->field("filepath");
+                  $category = $qQ->field("mime_category");
+                  switch ($category) {
+                    case "movie":
+                      $media = new MediaObject($src, $width, $height, $autostart, $loop, $showcontrols);
+                      switch ($display) {
+                        case "icon": $media->AsIcon($tooltip); break;
+                        case "link": $media->AsLink($tooltip); break;
+                      }
+                      break;
+                    case "audio":
+                      $media = new MediaObject($src, $width, $height, $autostart, $loop, $showcontrols);
+                      switch ($display) {
+                        case "icon": $media->AsIcon($tooltip); break;
+                        case "link": $media->AsLink($tooltip); break;
+                      }
+                      break;
+                    case "flash":
+                      $media = new FlashObject($src, $width, $height, $autostart, $loop);
+                      switch ($display) {
+                        case "icon": $media->AsIcon($tooltip); break;
+                        case "link": $media->AsLink($tooltip); break;
+                      }
+                      break;
+                    case "document":
+                      $media = new DocumentObject($src, $width, $height);
+                      switch ($display) {
+                        case "icon": $media->AsIcon($tooltip); break;
+                        case "link": $media->AsLink($tooltip, "_new"); break;
+                      }
+                      break;
+                  } // switch
+                  if (is_object($media)) {
+                    $new_content = $media->render();
+                  }
                 }
               }
-            }
-            break;
-        }// switch
-      } // got attributes
-
-      // Replace data tag with new content..
-      $content = str_replace($datatag, $new_content, $content);
+              break;
+          }// switch
+        } // got attributes
+  
+        // Replace data tag with new content..
+        $new_content = str_replace("<img ", "<AXYL_IMAGE ", $new_content);
+        $content = str_replace($datatag, $new_content, $content);
+      }
     } // while
 
     // Return the processed content..
+    $content = str_replace("<AXYL_IMAGE ", "<img ", $content);
     return $content;
 
   } // expanded_content
