@@ -44,7 +44,8 @@ class catalogitem extends RenderableObject {
   var $keywords = "";        // Any keywords associated with it
   var $category = "";        // Optional user-defined category for item
   var $filesize = "";        // Size of catalog item in bytes
-  var $filepath = "";        // Full local path to the item
+  var $filepath = "";        // Website URL path to the item (with leading '/')
+  var $physicalpath = "";    // Full physical path on the filesystem
   var $fileexists = false;   // True if file exists at filepath
   var $width = 0;            // Pixel width of this item
   var $height = 0;           // Pixel height of this item
@@ -72,12 +73,12 @@ class catalogitem extends RenderableObject {
     }
 
   } // catalogitem
-
   // .....................................................................
   /** Get current or nominated catalog item definition from the database.
   * @param integer $id Optional unique catalog item ID to get
   */
   function get($id=false) {
+    global $RESPONSE;
     $res = false;
     if ($id) $this->cat_id = $id;
     if ($this->cat_id) {
@@ -96,7 +97,8 @@ class catalogitem extends RenderableObject {
         $this->uploaded_ts   = datetime_to_timestamp($catQ->field("upload_timestamp"));
         $this->uploaded      = timestamp_to_displaydate(NICE_FULLDATETIME, $this->uploaded_ts);
         // Update status of physical file..
-        $this->fileexists = file_exists($this->filepath);
+        $this->physicalpath = $RESPONSE->site_docroot . $this->filepath;
+        $this->fileexists = file_exists($this->physicalpath);
         $res = true;
         $this->newcat = false;
       }
@@ -107,12 +109,12 @@ class catalogitem extends RenderableObject {
     $this->valid = $res;
     return $res;
   } // get
-
   // .....................................................................
   /** Save current catalog item definition to the database. Inserts
   * if brand new, else performs an update.
   */
   function save() {
+    global $RESPONSE;
     $res = false;
     if ($this->newcat || ($this->cat_id && $this->valid)) {
       if ($this->newcat) {
@@ -143,12 +145,12 @@ class catalogitem extends RenderableObject {
         // Index to Lucene..
         $this->index();
         // Update status of physical file..
-        $this->fileexists = file_exists($this->filepath);
+        $this->physicalpath = $RESPONSE->site_docroot . $this->filepath;
+        $this->fileexists = file_exists($this->physicalpath);
       }
     }
     return $res;
   } // save
-
   // .....................................................................
   /**
   * Remove the catalog item from the database and disk. This method
@@ -159,14 +161,18 @@ class catalogitem extends RenderableObject {
   * @return boolean True if the operation succeeded, else false.
   */
   function delete($deletefile=true) {
+    global $RESPONSE, $IMAGESDIR;
     $deleted = false;
     $err = false;
     if ($this->cat_id && $this->valid) {
       // First, deal to the physical file..
       if ($deletefile) {
-        if (file_exists($this->filepath)) {
-          if (!is_writeable($this->filepath) || !unlink($this->filepath)) {
-            $err = true;
+        if (file_exists($this->physicalpath)) {
+          // Avoid deleting images which are part of the standard issue..
+          if (substr($this->filepath, 0, strlen($IMAGESDIR)) != $IMAGESDIR) {
+            if (!is_writeable($this->physicalpath) || !unlink($this->physicalpath)) {
+              $err = true;
+            }
           }
         }
       }
@@ -185,7 +191,6 @@ class catalogitem extends RenderableObject {
     }
     return $deleted;
   }  // delete
-
   // .....................................................................
   /**
   * Index this catalog item to Lucene.
@@ -217,7 +222,6 @@ class catalogitem extends RenderableObject {
       $I->send();
     }
   } // index
-
   // .....................................................................
   /** Remove this catalog item from the Lucene index. */
   function unindex() {
@@ -228,13 +232,11 @@ class catalogitem extends RenderableObject {
       $UI->send();
     }
   } // unindex
-
   // .....................................................................
   /** Return the catalog item as a clickable icon.
   * @param boolean $autostart Movies etc. if true start automatically
   */
   function AsIcon($showcontrols=false, $autostart=false, $loop=false) {
-    global $LIBDIR, $CATALOGDIR;
     $icon = "";
     $tooltip = basename($this->filepath);
     // Set commonsense values for movies..
@@ -244,27 +246,27 @@ class catalogitem extends RenderableObject {
     }
     switch ($this->mime_category) {
       case "movie":
-        $media = new MediaObject($CATALOGDIR.'/'.basename($this->filepath), $this->width, $this->height, $autostart, $loop, $showcontrols);
+        $media = new MediaObject($this->filepath, $this->width, $this->height, $autostart, $loop, $showcontrols);
         $media->AsIcon($tooltip);
         $icon = $media->render();
         break;
       case "audio":
-        $media = new MediaObject($CATALOGDIR.'/'.basename($this->filepath), $this->width, $this->height, $autostart, $loop, $showcontrols);
+        $media = new MediaObject($this->filepath, $this->width, $this->height, $autostart, $loop, $showcontrols);
         $media->AsIcon($tooltip);
         $icon = $media->render();
         break;
       case "flash":
-        $media = new FlashObject($CATALOGDIR.'/'.basename($this->filepath), $this->width, $this->height, $autostart, $loop);
+        $media = new FlashObject($this->filepath, $this->width, $this->height, $autostart, $loop);
         $media->AsIcon($tooltip);
         $icon = $media->render();
         break;
       case "document":
-        $media = new DocumentObject($CATALOGDIR.'/'.basename($this->filepath), $this->width, $this->height);
+        $media = new DocumentObject($this->filepath, $this->width, $this->height);
         $media->AsIcon($tooltip);
         $icon = $media->render();
         break;
       case "image":
-        $media = new Img($CATALOGDIR.'/'.basename($this->filepath), $this->cat_name);
+        $media = new img($this->filepath, $this->cat_name);
         $media->AsIcon($tooltip);
         $icon = $media->render();
         break;
@@ -273,13 +275,11 @@ class catalogitem extends RenderableObject {
     } // switch
     return $icon;
   } // AsIcon
-
   // .....................................................................
   /** Return the catalog item as image, a clickable icon, or otherwise a link.
   * @param boolean $autostart Movies etc. if true start automatically
   */
   function Insitu($showcontrols=false, $autostart=false, $loop=false) {
-    global $LIBDIR, $CATALOGDIR;
     $catmedia = "";
     $tooltip = basename($this->filepath);
     // Set commonsense values for movies..
@@ -289,15 +289,19 @@ class catalogitem extends RenderableObject {
     }
     switch ($this->mime_category) {
       case "movie":
-        $media = new MediaObject($CATALOGDIR.'/'.basename($this->filepath), $this->width, $this->height, $autostart, $loop, $showcontrols);
+        $media = new MediaObject($this->filepath, $this->width, $this->height, $autostart, $loop, $showcontrols);
         $catmedia = $media->render();
         break;
       case "flash":
-        $media = new FlashObject($CATALOGDIR.'/'.basename($this->filepath), $this->width, $this->height, $autostart, $loop);
+        $media = new FlashObject($this->filepath, $this->width, $this->height, $autostart, $loop);
         $catmedia = $media->render();
         break;
       case "image":
-        $media = new img($CATALOGDIR.'/'.basename($this->filepath), $this->cat_name);
+        $media = new img(
+          $this->filepath,
+          str_replace(" ", "", $this->cat_name),
+          ($this->cat_desc != "" ? $this->cat_desc : $this->cat_name)
+          );
         $catmedia = $media->render();
         break;
       default:
@@ -305,17 +309,94 @@ class catalogitem extends RenderableObject {
     } // switch
     return $catmedia;
   } // In-situ
-
   // .....................................................................
   /** Return the catalog item as a clickable hyperlink. */
   function AsLink() {
-    global $LIBDIR, $CATALOGDIR;
-    include_once("button-defs.php");
-    $catlink = new Link( $CATALOGDIR.'/'.basename($this->filepath), $this->cat_name);
+    $catlink = new anchor($this->filepath, $this->cat_name);
     $catlink->set_linkover_text( basename($this->filepath) );
     return $catlink->render();
   } // AsLink
+  // .....................................................................
+  /**
+  * Create this catalog item from a media file on disk. The media item
+  * should be located at a physical path on disk somewhere. It will be grabbed,
+  * moved to a new location, and the item record saved to the DB.
+  * NOTE: this may be an existing catalogitem, OR a newly created one. This
+  * is not determined by this routine, but must be set up before calling this
+  * method. The save() method then does whatever is necessary.
+  * @param string $srcpath The full physical filesystem path to the source media
+  * @param string $destpath The full physical path of where to move the media
+  * @param string $filepath The relative path of the media, to save on DB record
+  * @param string $mimetype The mime type of the file, eg: "image/jpeg"
+  * @param string $name Media file associated name
+  * @param string $category Media file associated category
+  * @param string $desc Media file full description
+  * @param string $keywords Media file associated keywords
+  * @return boolean True if all ok, else false
+  */
+  function create(
+      $srcpath, $destpath, $filepath,
+      $mimetype="",
+      $width=0, $height=0,
+      $name="", $category="", $desc="", $keywords=""
+  ) {
+    global $RESPONSE;
 
+    // Valid flag..
+    $this->valid = false;
+
+    // Move file to destination & create our catalog record..
+    if (is_readable($srcpath)) {
+
+      // Determine mime-type
+      if ($mimetype == "") {
+        $mimetype = mimetype_from_filename($srcpath);
+      }
+      // Determine mime-category..
+      $mime_category = mimetype_category($mimetype);
+
+      // Size of this file..
+      $filesize = filesize($srcpath);
+
+      // Image metrics..
+      if ($mime_category == "image") {
+        $imginfo = getimagesize($srcpath);
+        $width  = $imginfo[0];
+        $height = $imginfo[1];
+      }
+      // Move to destination, if different to source location..
+      if (realpath($destpath) != realpath($srcpath)) {
+        if (copy($srcpath, $destpath) === false) {
+          $errmsgs[] = "failed to copy new media to its destination: $srcpath --> $destpath";
+        }
+      }
+      // Store file in database..
+      if ($name == "") {
+        $name = basename($srcpath);
+      }
+      $this->cat_name = $name;
+      $this->cat_desc = $desc;
+      $this->keywords = $keywords;
+      $this->category = $category;
+      $this->mime_category = $mime_category;
+      $this->mime_type = $mimetype;
+      $this->filesize = $filesize;
+      $this->filepath = $filepath;
+      $this->physicalpath = $destpath;
+      $this->fileexists = file_exists($destpath);
+      $this->width = $width;
+      $this->height = $height;
+      if ($this->save()) {
+        $this->valid = true;
+      }
+      else {
+        $errmsgs[] = "failed to save catalog item $this->cat_id to database.";
+      }
+    }
+    // Return the status..
+    return $this->valid;
+
+  } // create
   // .....................................................................
   /**
   * Process an uploaded media file, and define this catalog item to be
@@ -341,10 +422,14 @@ class catalogitem extends RenderableObject {
     if ($up->uploaded_count >= 1) {
       // Process uploaded file..
       $file_mime = $up->mimetype;
-      $path = "$CATALOGDIR/$up->filename";
-      debugbr($path);
-      // Check existence/overwrite
-      if (!file_exists($path) || isset($_overwrite)) {
+
+      // The relative URL path we will save on the DB record..
+      $filepath = "$CATALOGDIR/$up->filename";
+      // The physical path on the filesystem..
+      $destpath = $RESPONSE->site_docroot . $filepath;
+
+      // Check pre-existence/overwrite flag..
+      if (!file_exists($destpath) || isset($_overwrite)) {
         // Determine mime_category..
         if ($mime_category == "" ) {
           $mime_category = mimetype_category($file_mime);
@@ -359,31 +444,29 @@ class catalogitem extends RenderableObject {
         // Carry on if legal mime_category..
         if ($mime_category != "") {
           // Store file in catalog..
-          if ($up->store($RESPONSE->site_docroot.$CATALOGDIR)) {
-            // Image metrics..
-            $width = 0; $height = 0;
-            if ($mime_category == "image") {
-              if (extension_loaded("gd") && file_exists($path)) {
-                $szinfo = getimagesize($path);
-                $width = $szinfo[0];
-                $height = $szinfo[1];
+          $srcpath = tempnam("/tmp", "CATA");
+          $tempdir = dirname($srcpath);
+          $tempfname = basename($srcpath);
+          if ($up->store($tempdir, $tempfname)) {
+
+            // If we are doing this from a microsite, then possibly
+            // assign the category, if not already assigned..
+            if ($RESPONSE->microsites_mode == MICROSITES_ENABLED) {
+              if ($RESPONSE->microsite_detected != "" && $category == "") {
+                $category = $RESPONSE->microsite_detected;
               }
             }
-            // Store file in database..
-            if ($name == "") {
-              $name = basename($path);
+            // Move new media file into place, and save data to DB..
+            $this->create(
+                    $srcpath, $destpath, $filepath,
+                    $file_mime,
+                    0, 0,
+                    $name, $category, $desc, $keywords
+                    );
+            // Tidy up temporary file..
+            if (is_writeable($srcpath)) {
+              unlink($srcpath);
             }
-            $this->cat_name = $name;
-            $this->cat_desc = $desc;
-            $this->keywords = $keywords;
-            $this->category = $category;
-            $this->mime_category = $mime_category;
-            $this->mime_type = $file_mime;
-            $this->filesize = $up->filesize;
-            $this->filepath = $path;
-            $this->width = $width;
-            $this->height = $height;
-            $this->valid = $this->save();
           }
           else {
             $errmsgs[] = $up->error_message();
@@ -403,7 +486,6 @@ class catalogitem extends RenderableObject {
     }
     return $errmsgs;
   } // upload
-
   // .....................................................................
   /**
   * Render the catalog item. We render it as either and icon or a link,
@@ -439,7 +521,6 @@ class catalog extends RenderableObject {
   var $catalogitems = array();
   /** The array of categories (optional) */
   var $categories = array();
-
   // .....................................................................
   /** Constructor */
   function catalog($catalogitems=false) {
@@ -447,7 +528,6 @@ class catalog extends RenderableObject {
       $this->catalogitems = $catalogitems;
     }
   } // catalog
-
   // .....................................................................
   /** Return the count of items in the catalog currently.
   * @return integer Count of items in the catalog.
@@ -468,7 +548,6 @@ class catalog extends RenderableObject {
       $this->categories = $categories;
     }
   } // define_categories
-
   // .....................................................................
   /**
   * Add catalog item to the catalog. The catalog will add the new item
@@ -480,7 +559,24 @@ class catalog extends RenderableObject {
       $this->catalogitems[$catitem->cat_id] = $catitem;
     }
   } // additem
-
+  // .....................................................................
+  /**
+  * Find a catalogitem by filepath. Just trawls the array of catalog
+  * items in this catalog comparing filepaths. Returns false if not found
+  * else a copy of the catalogitem object.
+  * @param string $filepath Website URL that image is located at.
+  * @return mixed False if we didn't match a filepath, else catalog item copy.
+  */
+  function get_catalogitem_by_filepath($filepath) {
+    $found = false;
+    foreach ($this->catalogitems as $catitem) {
+      if ($catitem->filepath == $filepath) {
+        $found = $catitem;
+        break;
+      }
+    }
+    return $found;
+  } // get_catalogitem_by_filepath
   // .....................................................................
   /**
   * Perform a search for catalog items. This method will use Lucene
@@ -575,7 +671,7 @@ class catalog extends RenderableObject {
       $thesearch->execute();
 
       // Populate the catalog..
-      if ($thesearch->hitcount > 0) {
+      if ($thesearch->hitcount() > 0) {
         foreach ($thesearch->hit as $hit) {
           $ci = new catalogitem();
           $bits = explode("_", $hit["Id"]);
@@ -655,7 +751,6 @@ class catalog extends RenderableObject {
     }
 
   } // search
-
   // .....................................................................
   /** Return the HTML for this catalog. Returns the list of catalog items
   * as an HTML table.
