@@ -66,29 +66,37 @@ class datasources {
   * @param string  $passwd    The password the user can access the database with
   * @param string  $host      The hostname of the machine running the database (TCP/IP)
   * @param integer $port      The port number of the database server
+  * @param string  $enc       The database character encoding
+  * @param string  $datestyle The database date style
   * @param boolean $default   True if the database is the default database
   */
-  function add_database($dbtype, $name, $user="", $passwd="", $host="", $port=0, $default=false) {
+  function add_database(
+          $dbtype,
+          $name, $user="", $passwd="",
+          $host="", $port=0,
+          $enc="", $datestyle="",
+          $default=false)
+  {
     switch ($dbtype) {
       case "postgres":
         include_once("db-postgres.php");
-        $this->database[$name] = new db_postgres($name, $user, $passwd, $host, $port);
+        $this->database[$name] = new db_postgres($name, $user, $passwd, $host, $port, $enc, $datestyle);
         break;
       case "odbc":
         include_once("db-odbc.php");
-        $this->database[$name] = new db_odbc($name, $user, $passwd, $host, $port);
+        $this->database[$name] = new db_odbc($name, $user, $passwd, $host, $port, $enc, $datestyle);
         break;
       case "mssql_server":
         include_once("db-mssql-server.php");
-        $this->database[$name] = new db_mssql_server($name, $user, $passwd, $host, $port);
+        $this->database[$name] = new db_mssql_server($name, $user, $passwd, $host, $port, $enc, $datestyle);
         break;
       case "mysql":
         include_once("db-mysql.php");
-        $this->database[$name] = new db_mysql($name, $user, $passwd, $host, $port);
+        $this->database[$name] = new db_mysql($name, $user, $passwd, $host, $port, $enc, $datestyle);
         break;
       case "oracle":
         include_once("db-oracle.php");
-        $this->database[$name] = new db_oracle($name, $user, $passwd, $host, $port);
+        $this->database[$name] = new db_oracle($name, $user, $passwd, $host, $port, $enc, $datestyle);
         break;
     }
     // Make sure the default database is selected..
@@ -557,6 +565,10 @@ class database {
   var $user = "";
   /** Default password to connect as */
   var $passwd = "";
+  /** The database internal date format/style */
+  var $datestyle = "UNICODE";
+  /** The database character encoding */
+  var $enc = "";
   /** Flag true if database was connected ok */
   var $connected = false;
 
@@ -581,13 +593,15 @@ class database {
   // ....................................................................
   /**
   * Constructor
-  * @param string  $name    The database name
-  * @param string  $user    The username of user who can access the database
-  * @param string  $passwd  The user password which can access the database
-  * @param string  $host    The hostname of the machine running the database
-  * @param integer $port    The port number of the database server
+  * @param string  $name      The database name
+  * @param string  $user      The username of user who can access the database
+  * @param string  $passwd    The user password which can access the database
+  * @param string  $host      The hostname of the machine running the database
+  * @param integer $port      The port number of the database server
+  * @param string  $enc       The database character encoding (database dependent)
+  * @param string  $datestyle The database date style (eg. 'ISO')
   */
-  function database($name="", $user="", $passwd="", $host="", $port=0) {
+  function database($name="", $user="", $passwd="", $host="", $port=0, $enc="", $datestyle="") {
     $this->name = $name;
 
     // If host and port ar not specified, then
@@ -599,6 +613,10 @@ class database {
     $this->user = $user;
     $this->passwd = $passwd;
 
+    // Database dates and chars..
+    $this->enc = $enc;
+    $this->datestyle = $datestyle;
+
     // Timer..
     $this->timer = new microtimer();
   } // database
