@@ -264,8 +264,8 @@ function displaydate_to_timestamp($displaydate) {
 * @return string  Datetime string in ISO YYYY-MM-DD HH:MM:SS format
 */
 function timestamp_to_datetime($timestamp=false) {
-  $res = FALSE;
-  if (!$timestamp) {
+  $res = false;
+  if ($timestamp === false) {
     $timestamp = time();
   }
   $res = date(ISO_DATABASE_FORMAT, $timestamp);
