@@ -36,8 +36,8 @@
 */
 class db_odbc extends database {
   /** Constructor */
-  function db_odbc($name="", $user="", $passwd="", $host="", $port=0) {
-    $this->database($name, $user, $passwd, $host, $port);
+  function db_odbc($name="", $user="", $passwd="", $host="", $port=0, $enc="", $datestyle="") {
+    $this->database($name, $user, $passwd, $host, $port, $enc, $datestyle);
     $this->type = "odbc";
   }
   // ....................................................................
