@@ -208,7 +208,7 @@ class forum extends HTMLObject {
 
   function html () {
     // display the html required for the page.
-    global $RESPONSE, $mode, $forum_id, $thread_id;
+    global $RESPONSE, $LIBDIR, $mode, $forum_id, $thread_id;
     global $SaveForum_x, $BackForum_x, $CancelForum_x, $locked, $sticky;
     global $SaveThread_x, $BackThread_x, $CancelThread_x;
     global $SaveMsg_x, $BackMsg_x, $CancelMsg_x, $hide, $msg_id, $thread_id;
@@ -241,7 +241,7 @@ class forum extends HTMLObject {
         // create and edit forums
         if ( $RESPONSE->ismemberof_group_in("Admin,Editor") ) {
           $T->tr();
-          $T->td("Create/Edit Forum Details", "forumheadings" );
+          $T->td("Create/Edit Forum Details", "axforumformheadings" );
           $T->td_colspan(2);
           $T->tr();
           $T->td("<hr>");
@@ -260,7 +260,7 @@ class forum extends HTMLObject {
             $fidlabel = new form_labelfield("fid", $this->forum_id);
             $fidlabel->setclass("axfmlbl");
             $T->tr();
-            $T->td("Forum Id: ", "forumlabels");
+            $T->td("Forum Id: ", "axforumform");
             $T->td_width("20%");
             $T->td_alignment("right");
             $T->td($fidlabel->render());
@@ -271,7 +271,7 @@ class forum extends HTMLObject {
           $forumname->setstyle("width: 250");
           $forumname->setclass("axtxtbox");
           $T->tr();
-          $T->td("Forum Name: ", "forumlabels");
+          $T->td("Forum Name: ", "axforumform");
           $T->td_width("20%");
           $T->td_alignment("right");
           $T->td($forumname->render());
@@ -281,11 +281,24 @@ class forum extends HTMLObject {
           $forumdesc->setstyle("width: 250");
           $forumdesc->setclass("axmemo");
           $T->tr();
-          $T->td("Forum Desc: ", "forumlabels");
+          $T->td("Forum Desc: ", "axforumform");
           $T->td_width("20%");
           $T->td_alignment("right", "top");
           $T->td($forumdesc->render());
 
+          // Private
+          $forumpriv = new form_checkbox("private");
+          if ($this->private) {
+            $forumpriv->check();
+          } else {
+            $forumpriv->uncheck();
+          }
+          $T->tr();
+          $T->td("Private: ", "axforumform");
+          $T->td_width("20%");
+          $T->td_alignment("right");
+          $T->td($forumpriv->render(), "axchkbox");
+
           // Enabled
           $forumenabled = new form_checkbox("enabled");
           if ($this->enabled) {
@@ -294,7 +307,7 @@ class forum extends HTMLObject {
             $forumenabled->uncheck();
           }
           $T->tr();
-          $T->td("Enabled: ", "forumlabels");
+          $T->td("Enabled: ", "axforumform");
           $T->td_width("20%");
           $T->td_alignment("right");
           $T->td($forumenabled->render(), "axchkbox");
@@ -317,14 +330,14 @@ class forum extends HTMLObject {
           $forummoderator->setclass("axlistbox");
           $forummoderator->add_querydata($FM, "user_id", "user_id");
           $T->tr();
-          $T->td("Moderator(s): ", "forumlabels");
+          $T->td("Moderator(s): ", "axforumform");
           $T->td_width("20%");
           $T->td_alignment("right", "top");
           $T->td($forummoderator->render());
 
           // POST button
-          $pb = new form_imagebutton("SaveForum", "SaveForum", "", "lib/_save.gif", "", 57, 15);
-          $cb = new form_imagebutton("CancelForum", "CancelForum", "", "lib/_cancel.gif", "", 57, 15);
+          $pb = new form_imagebutton("SaveForum", "SaveForum", "", "$LIBDIR/img/_save.gif", "", 57, 15);
+          $cb = new form_imagebutton("CancelForum", "CancelForum", "", "$LIBDIR/img/_cancel.gif", "", 57, 15);
           $T->tr();
           $T->td("&nbsp;");
           $T->td($cb->render() . " " . $pb->render());
@@ -408,34 +421,33 @@ class forum extends HTMLObject {
           }
 
           // display the forum threads.
-          debugbr("IS THIS FORUM ENABLED? $this->enabled");
-          debugbr("IS THIS FORUM name? $this->forum_name");
           $T->tr();
-          $fl = "<a href=\"?mode=\" class=\"forumlink\">Forum List</a>";
-          $T->td("$fl >> <b>$this->forum_name</b>");
+          $fl = "<a href=\"?mode=\"><span class=\"axforumsectionnav\">Forum List</span></a>";
+          $T->td("$fl >> <b>$this->forum_name</b>", "axforumsectionnav");
           if ( !$RESPONSE->ismemberof_group("guest") && $this->enabled ) {
-            $T->td("<a href=\"$RESPONSE->requested?mode=newthread&forum_id=$this->forum_id\" class=\"forumlink\">[New Topic]</a>");
+          	$href = "$RESPONSE->requested?mode=newthread&forum_id=$this->forum_id";
+            $T->td("<a href=\"$href\"><span class=\"axforumsectionnav\">[NEW TOPIC]</span></a>");
             $T->td_colspan(3);
             $T->td_alignment("right");
           } else {
             $T->td_colspan(4);
           }
           $T->tr();
-          $T->td("Topic", "threadtitle");
-          $T->td_alignment("center");
+          $T->td("Topic", "axthreadtitle");
+          $T->td_alignment("left");
           $T->td_width("70%");
-          $T->td("Replies", "threadtitle");
+          $T->td("Replies", "axthreadtitle");
           $T->td_alignment("center");
           $T->td_width("5%");
-          $T->td("Author", "threadtitle");
+          $T->td("Author", "axthreadtitle");
           $T->td_alignment("center");
           $T->td_width("20%");
-          $T->td("Views", "threadtitle");
+          $T->td("Views", "axthreadtitle");
           $T->td_alignment("center");
           $T->td_width("5%");
-          /*$T->tr();
-          $T->td("&nbsp;");
-          $T->td_colspan(4);*/
+          $T->tr();
+          $T->td("<hr>");
+          $T->td_colspan(4);
 
           // display the thread header messages
           if ( count($this->forum_threads) > 0 ) {
@@ -448,20 +460,25 @@ class forum extends HTMLObject {
 
               if ($thread->enabled) {
                 if ($thread->locked && !$thread->sticky) {
-                  //debugbr("<font color=\"red\">THREAD LOCKED AND ENABLED</font>");
-                  $tname = "<a href=\"$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread\" class=\"locked\">$thread->subject</a>";
+                  debugbr("<font color=\"red\">THREAD LOCKED AND ENABLED</font>");
+                  $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread";
+                  $tname = "<a href=\"$href\"><span class=\"axlocked\">$thread->subject</span></a>";
                 } elseif (!$thread->locked && $thread->sticky) {
-                  //debugbr("<font color=\"red\">THREAD STICKY AND ENABLED</font>");
-                  $tname = "STICKY: <a href=\"$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread\">".strtoupper($thread->subject)."</a>";
+                  debugbr("<font color=\"red\">THREAD STICKY AND ENABLED</font>");
+                  $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread";
+                  $tname = "STICKY: <a href=\"$href\"><span class=\"axforumlink\">".strtoupper($thread->subject)."</span></a>";
                 } elseif ($thread->locked && $thread->sticky) {
-                  //debugbr("<font color=\"red\">THREAD LOCKED AND STICKY AND ENABLED</font>");
-                  $tname = "STICKY: <a href=\"$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread\" class=\"locked\">".strtoupper($thread->subject)."</a>";
+                  debugbr("<font color=\"red\">THREAD LOCKED AND STICKY AND ENABLED</font>");
+                  $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread";
+                  $tname = "STICKY: <a href=\"$href\"><span class=\"axlocked\">".strtoupper($thread->subject)."</span></a>";
                 } else {
-                  //debugbr("<font color=\"red\">THREAD UNLOCKED AND NOT STICKY AND ENABLED</font>");
-                  $tname = "<a href=\"$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread\" class=\"forumlink\">$thread->subject</a>";
+                  debugbr("<font color=\"red\">THREAD UNLOCKED AND NOT STICKY AND ENABLED</font>");
+                  $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread";
+                  $tname = "<a href=\"$href\"><span class=\"axforumlink\">$thread->subject</span></a>";
                 }
               } else {
-                $tname = "<a href=\"$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread\"><font color=\"red\"><i>$thread->subject</i></font></a>";
+              	$href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread";
+                $tname = "<a href=\"$href\"><span class=\"axforumlocked\">$thread->subject</span></a>";
               }
 
               if ( $RESPONSE->ismemberof_group_in("Admin,Editor") || $RESPONSE->userid == trim($thread->moderator) ) {
@@ -469,39 +486,39 @@ class forum extends HTMLObject {
                   if (!$thread->locked) {
                     //debugbr("<font color=\"red\">THREAD UNLOCKED</font>");
                     $tname .= "<br>";
-                    $tname .= "<a href=\"$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&locked=1\" class=\"forumlinkother\">";
-                    $tname .= "[LOCK]</a>";
+                    $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&locked=1";
+                    $tname .= "<a href=\"$href\"><span class=\"axforumlinkother\">[LOCK]</span></a>";
                   } else {
                     //debugbr("<font color=\"red\">THREAD LOCKED</font>");
                     $tname .= "<br>";
-                    $tname .= "<a href=\"$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&locked=0\" class=\"forumlinkother\">";
-                    $tname .= "[UNLOCK]</a>";
+                    $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&locked=0";
+                    $tname .= "<a href=\"$href\"><span class=\"axforumlinkother\">[UNLOCK]</span></a>";
                   }
 
                   if (!$thread->sticky) {
                     //debugbr("<font color=\"red\">THREAD NOT STICKY</font>");
-                    $tname .= "<a href=\"$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&sticky=1\" class=\"forumlinkother\">";
-                    $tname .= "[STICK]</a>";
+                    $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&sticky=1";
+                    $tname .= "<a href=\"$href\"><span class=\"axforumlinkother\">[STICK]</span></a>";
                   } else {
                     //debugbr("<font color=\"red\">THREAD STICKY</font>");
-                    $tname .= "<a href=\"$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&sticky=0\" class=\"forumlinkother\">";
-                    $tname .= "[UNSTICK]</a>";
+                    $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&sticky=0";
+                    $tname .= "<a href=\"$href\"><span class=\"axforumlinkother\">[UNSTICK]</span></a>";
                   }
                 }
               }
 
 
               $T->tr();
-              $T->td("$tname");
+              $T->td("$tname", "axforumnonlink");
               $T->td_width("70%");
               $T->td_alignment("left");
-              $T->td($thread->replies);
+              $T->td($thread->replies, "axforumnonlink");
               $T->td_width("5%");
               $T->td_alignment("center");
-              $T->td($thread->author);
+              $T->td($thread->author, "axforumnonlink");
               $T->td_width("20%");
               $T->td_alignment("center");
-              $T->td($thread->views);
+              $T->td($thread->views, "axforumnonlink");
               $T->td_width("5%");
               $T->td_alignment("center");
               $T->tr();
@@ -569,7 +586,8 @@ class forum extends HTMLObject {
         if ( $this->forum_threads[$thread_id] ) {
           $thread = $this->forum_threads[$thread_id];
           debugbr("thread object: $thread");
-          if ( !isset($BackMsg_x) && !isset($CancelMsg_x) && !isset($SaveThread_x) && !isset($SaveMsg_x) && trim($mode) != "edmsg" ) {
+          if ( !isset($BackMsg_x) && !isset($CancelMsg_x) && !isset($SaveThread_x) && 
+               !isset($SaveMsg_x) && trim($mode) != "edmsg" ) {
             $thread->inc_thread_views();
           }
 
@@ -602,7 +620,6 @@ class forum extends HTMLObject {
         //break;
       default:
         // display the forums that already exist.
-        // and are not disabled
         debugbr("this is the default mode. displaying the forums list");
         $q = "select * from ax_forum";
         if ( !$RESPONSE->ismemberof_group_in("Admin,Editor") ) {
@@ -614,15 +631,16 @@ class forum extends HTMLObject {
         $T->td("&nbsp;");
         $T->td_colspan(3);
         $T->tr();
-        $T->td($this->forum_title, "forumgreetingdisp");
+        $T->td($this->forum_title, "axforumtitle");
         $T->td_colspan(4);
         $T->td_alignment("left");
         $T->tr();
-        $T->td("Forum Name", "forumtitle" );
+        $T->td("Forum Name", "axforumtitle" );
         if ( $RESPONSE->ismemberof_group_in("Admin,Editor") ) {
-          $T->td("<a href=\"$RESPONSE->requested?forum_id=".NEW_FORUM."&mode=new\" class=\"forumlinkwhite\">[NEW FORUM]</a>", "forumtitle" );
+          $href = "$RESPONSE->requested?forum_id=".NEW_FORUM."&mode=new";
+          $T->td("<a href=\"$href\"><span class=\"axnewforumlink\">[NEW FORUM]</span></a>", "axnewforumlink" );
         } else {
-          $T->td("&nbsp;", "forumtitle");
+          $T->td("&nbsp;", "axnewforumlink");
         }
         $T->td_colspan(3);
         $T->td_alignment("center");
@@ -634,21 +652,27 @@ class forum extends HTMLObject {
         if ( $qQ->hasdata ) {
           do {
             if (!$qQ->istrue("enabled")) {
-              $fname = "<a href=\"$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=view\" class=\"disabled\">".strtoupper($qQ->field("forum_name"))."</a>";
+              $href = "$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=view";
+              $fname = "<a href=\"$href\"><span class=\"axforumlocked\">".strtoupper($qQ->field("forum_name"))."</span></a>";
             } else {
-              $fname = "<a href=\"$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=view\" class=\"forumlink\">".strtoupper($qQ->field("forum_name"))."</a>";
+              $href = "$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=view";
+              $fname = "<a href=\"$href\"><span class=\"axforumlink\">".strtoupper($qQ->field("forum_name"))."</span></a>";
             }
+            $fname .= "<br><span class=\"axforumdesc\">".$qQ->field("forum_desc")."</span>";
             $T->tr();
             $T->td("$fname");
             $T->td_width("80%");
             if ( $RESPONSE->ismemberof_group_in("Admin,Editor") ) {
-              $T->td("<a href=\"$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=edit\" class=\"forumlink\">[EDIT]</a>");
+              $href = "$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=edit";
+              $T->td("<a href=\"$href\"><span class=\"axforumlink\">[EDIT]</span></a>");
               $T->td_width("10%");
               $T->td("&nbsp;");
               if (!$qQ->istrue("enabled")) {
-                $T->td("<a href=\"$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=hidden&hide=t\" class=\"forumlink\">[ENABLE]</a>");
+              	$href = "$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=hidden&hide=t";
+                $T->td("<a href=\"$href\"><span class=\"axforumlink\">[ENABLE]</span></a>");
               } else {
-                $T->td("<a href=\"$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=hidden&hide=f\" class=\"forumlink\">[DISABLE]</a>");
+              	$href = "$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=hidden&hide=f";
+                $T->td("<a href=\"$href\"><span class=\"axforumlink\">[DISABLE]</span></a>");
               }
               $T->td_width("10%");
             } else {
@@ -972,17 +996,18 @@ class forum_thread extends forum {
         $T = new table("ForumThread");
         $T->setpadding(4,1);
         $T->setborder(0);
-        $T->setwidth("80%");
+        $T->setwidth("100%");
         $T->setalign("center");
 
         // thread header
         $T->tr();
-        $tl = "<a href=\"$RESPONSE->requested?mode=view&forum_id=$forum_id\" class=\"forumlink\">Thread List</a>";
-        $fl = "<a href=\"$RESPONSE->requested?mode=\" class=\"forumlink\">Forum List</a>";
+        $href = "$RESPONSE->requested?mode=view&forum_id=$forum_id";
+        $tl = "<a href=\"$href\"><span class=\"axforumsectionnav\">Thread List</span></a>";
+        $fl = "<a href=\"$RESPONSE->requested?mode=\"><span class=\"axforumsectionnav\">Forum List</span></a>";
         if ($this->locked) {
-          $T->td("$fl >> $tl >> <b>$this->subject (This thread has been LOCKED)</b>");
+          $T->td("$fl >> $tl >> <b>$this->subject (This thread has been LOCKED)</b>", "axforumsectionnav");
         } else {
-          $T->td("$fl >> $tl >> <b>$this->subject</b>");
+          $T->td("$fl >> $tl >> <b>$this->subject</b>", "axforumsectionnav");
         }
         $T->td_colspan(2);
         $T->tr();
@@ -991,23 +1016,26 @@ class forum_thread extends forum {
         // display the thread header message
         // subject
         $T->tr();
-        $T->td("<b>$this->subject</b>", "forumtitle" );
+        $T->td("<span class=\"axmsgtitle\">$this->subject</span>");
         $T->td_contentcss("font-size:10pt");
         $T->td_alignment("left");
         $T->td_colspan(2);
 
         // message info and controls
         if ($this->enabled && !$this->locked) {
-          $quote = "<a href=\"$RESPONSE->requested?mode=reply&forum_id=$this->forum_id&thread_id=$this->thread_id&quote=$this->thread_id\" class=\"forumlinkother\">[REPLY]</a>";
+          $href = "$RESPONSE->requested?mode=reply&forum_id=$this->forum_id&thread_id=$this->thread_id&quote=$this->thread_id";
+          $quote = "<a href=\"$href\"><span class=\"axmsglinkother\">[REPLY]</span></a>";
         } else {
           $quote = "&nbsp;";
         }
         if ( $RESPONSE->ismemberof_group_in("Admin,Editor")  || $RESPONSE->userid == trim($this->moderator) ) {
-          $dthd = "<a href=\"$RESPONSE->requested?mode=delthd&msg_id=$this->thread_id&forum_id=$this->forum_id&thread_id=$this->thread_id\" class=\"forumlinkother\">[DELETE]</a>";
-          $ethd = "<a href=\"$RESPONSE->requested?mode=edmsg&msg_id=$this->thread_id&forum_id=$this->forum_id&thread_id=$this->thread_id\" class=\"forumlinkother\">[EDIT]</a>";
+          $href = "$RESPONSE->requested?mode=delthd&msg_id=$this->thread_id&forum_id=$this->forum_id&thread_id=$this->thread_id";
+          $dthd = "<a href=\"$href\"><span class=\"axmsglinkother\">[DELETE]</span></a>";
+          $href = "$RESPONSE->requested?mode=edmsg&msg_id=$this->thread_id&forum_id=$this->forum_id&thread_id=$this->thread_id";
+          $ethd = "<a href=\"$href\"><span class=\"axmsglinkother\">[EDIT]</span></a>";
         }
         $T->tr();
-        $T->td("Thread last updated on $this->date_posted", "forummsginfo" );
+        $T->td("Posted by ".ucwords($this->author)." on $this->date_posted", "axmsgpostinfo");
         if ( !$RESPONSE->ismemberof_group("guest") ) {
           $T->td($quote."&nbsp;".$dthd."&nbsp;".$ethd);
           $T->td_width("20%");
@@ -1015,7 +1043,7 @@ class forum_thread extends forum {
 
         // message body
         $T->tr();
-        $T->td(str_replace("\n", "<br>", $this->text));
+        $T->td(str_replace("\n", "<br>", $this->text), "axmsgtext");
         $T->td_alignment("left", "top");
         $T->td_colspan(2);
 
@@ -1035,23 +1063,26 @@ class forum_thread extends forum {
               $T->td_colspan(2);
             }
             $T->tr();
-            $T->td("<b>$msg->msg_subject</b>");
+            $T->td("<span class=\"axmsgtitle\">$msg->msg_subject</span>");
             $T->td_contentcss("font-size:10pt");
             $T->td_alignment("left");
             $T->td_colspan(2);
 
             // message info and controls
             if ($this->enabled && !$this->locked) {
-              $quote = "<a href=\"$RESPONSE->requested?mode=reply&forum_id=$msg->forum_id&thread_id=$msg->thread_id&quote=$msg->msg_id\" class=\"forumlinkother\">[REPLY]</a>";
+          	  $href = "$RESPONSE->requested?mode=reply&forum_id=$msg->forum_id&thread_id=$msg->thread_id&quote=$msg->msg_id";
+              $quote = "<a href=\"$href\"><span class=\"axmsglinkother\">[REPLY]</span></a>";
             } else {
               $quote = "&nbsp;";
             }
             if ( $RESPONSE->ismemberof_group_in("Admin,Editor")  || $RESPONSE->userid == trim($this->moderator)) {
-              $dmsg = "<a href=\"$RESPONSE->requested?mode=delmsg&msg_id=$msg->msg_id&forum_id=$msg->forum_id&thread_id=$msg->thread_id\" class=\"forumlinkother\">[DELETE]</a>";
-              $ethd = "<a href=\"$RESPONSE->requested?mode=edmsg&msg_id=$msg->msg_id&forum_id=$msg->forum_id&thread_id=$msg->thread_id\" class=\"forumlinkother\">[EDIT]</a>";
+              $href = "$RESPONSE->requested?mode=delmsg&msg_id=$msg->msg_id&forum_id=$msg->forum_id&thread_id=$msg->thread_id";
+              $dmsg = "<a href=\"$href\"><span class=\"axmsglinkother\">[DELETE]</span></a>";
+              $href = "$RESPONSE->requested?mode=edmsg&msg_id=$msg->msg_id&forum_id=$msg->forum_id&thread_id=$msg->thread_id";
+              $ethd = "<a href=\"$href\"><span class=\"axmsglinkother\">[EDIT]</span></a>";
             }
             $T->tr();
-            $T->td("Posted by $msg->author on $msg->date_posted", "forumlinkother" );
+            $T->td("Posted by ".ucwords($msg->author)." on $msg->date_posted", "axmsgpostinfo" );
             if ( !$RESPONSE->ismemberof_group("guest") ) {
               $T->td($quote."&nbsp;".$dmsg."&nbsp;".$ethd);
               $T->td_width("20%");
@@ -1059,12 +1090,40 @@ class forum_thread extends forum {
 
             // message body
             $T->tr();
-            $T->td(str_replace("\n", "<br>", $msg->msg_text));
+            //$msg_text = strtolower($msg->msg_text)
+            // do some string replacements
+            $msg_text = str_replace("\n", "<br>", $msg->msg_text);
+            
+            $qs = strstr($msg_text, "[quote]");
+            if ( trim($qs) != "" ) {
+            	$msg = substr($qs, strpos($qs, '[/quote]')+8);
+	            $qs = substr($qs, 0, strpos($qs, '[/quote]')+8);
+	            $qs = str_replace("[quote]", "", $qs);
+	            $qs = str_replace("[/quote]", "", $qs);
+	            
+	            // make a table wrapper
+	            $TQ = new table("QuotedFromTable");
+	            $TQ->setwidth("50%");
+	            $TQ->setcss("axquotetable");
+	            //$TQ->setborder(1);
+	            $TQ->tr("axquotetable");
+	            $TQ->td("Quote","axqoutedbanner");
+	            $TQ->tr();
+	            $TQ->td($qs, "axqoutedtext");
+	            
+	            $quote = $TQ->render();
+            } else {
+            	$quote = "";
+            	$msg = $msg_text;
+            }
+            $msg_text = $quote . $msg;
+            //$msg_text = str_replace("\n", "<br>", $msg_text);
+            $T->td($msg_text, "axmsgtext");
             $T->td_alignment("left", "top");
             $T->td_colspan(2);
 
             $temp = "fish";
-          }
+          } // foreach (thread message)
         }
         $s = $T->render();
       } // switch ($mode)
@@ -1153,7 +1212,8 @@ class thread_msg extends forum_thread {
       $query->set("msg_id", $mid);
       $query->set("parent_thread_id", $this->thread_id);
       $query->set("msg_author", $this->author);
-      $query->set("last_modified", $this->date_posted);
+      //$query->set("last_modified", $this->date_posted);
+      $query->set("last_modified", 'now()');
       $query->set("forum_id", trim($forum_id));
       $query->set("enabled", $this->enabled);
       $query->set("sticky", $this->sticky);
@@ -1217,7 +1277,7 @@ class thread_msg extends forum_thread {
 
   function new_msg() {
     // displays the form objects for entering in a new message.
-    global $RESPONSE, $forum_id, $mode;
+    global $RESPONSE, $LIBDIR, $forum_id, $mode;
     global $msg_subject, $msg_text;
     global $quote;
 
@@ -1243,8 +1303,9 @@ class thread_msg extends forum_thread {
         $this->msg_subject = "RE: ".$Q->field("msg_subject");
         $oldtxt = $Q->field("msg_text");
 
-        $this->msg_text  = ">----------\nPosted by ".$Q->field("msg_author")." on ". $Q->field("date_posted").":";
-        $this->msg_text .= "\n\n".$Q->field("msg_text")."\n>----------\n\n";
+		$quote = str_replace("[quote]", "", $Q->field("msg_text"));
+		$quote = str_replace("[/quote]", "", $quote);
+        $this->msg_text  = "[quote]".$quote."[/quote]\n\n";
       }
     }
 
@@ -1264,32 +1325,35 @@ class thread_msg extends forum_thread {
 
     if ( trim($this->thread_id) != NEW_THREAD ) {
       $T->tr();
-      $T->td("Subject:&nbsp;");
+      $T->td("Subject:&nbsp;", "axforumform");
       $T->td_alignment("right");
       $T->td_width("25%");
-      $T->td("$oldsub");
+      $T->td($oldsub, "axmsgtitle");
       $T->tr();
-      $T->td("Text:&nbsp;");
+      $T->td("Text:&nbsp;", "axforumform");
       $T->td_alignment("right", "top");
       $T->td_width("25%");
-      $T->td(str_replace("\n", "<br>", $oldtxt));
+      $oldtxt = str_replace("[quote]", "", $oldtxt);
+	  $oldtxt = str_replace("[/quote]", "", $oldtxt);
+	  $oldtxt = str_replace("\n", "<br>", $oldtxt);
+      $T->td($oldtxt, "axmsgtext");
       $T->tr();
       $T->td("<hr>");
       $T->td_colspan(2);
 
-      $pb = new form_imagebutton("SaveMsg", "Save Msg", "", "lib/_save.gif", "", 57, 15);
-      $cb = new form_imagebutton("CancelMsg", "Cancel", "", "lib/_cancel.gif", "", 57, 15);
-      //$bb = new form_imagebutton("BackMsg", "Back To Msgs", "", "lib/_back.gif", "", 42, 15);
+      $pb = new form_imagebutton("SaveMsg", "Save Msg", "", "$LIBDIR/img/_save.gif", "", 57, 15);
+      $cb = new form_imagebutton("CancelMsg", "Cancel", "", "$LIBDIR/img/_cancel.gif", "", 57, 15);
+      //$bb = new form_imagebutton("BackMsg", "Back To Msgs", "", "$LIBDIR/img/_back.gif", "", 42, 15);
     } else {
       $T->tr();
       $T->td("&nbsp;");
-      $T->td("NEW THREAD", "forumheadings");
+      $T->td("NEW THREAD", "axforumformheadings");
       /*$T->td_contentcss("font-size:12pt;
                          color: #FF6600;
                          font-weight: bold;");*/
-      $pb = new form_imagebutton("SaveThread", "Save Thread", "", "lib/_save.gif", "", 57, 15);
-      $cb = new form_imagebutton("CancelThread", "Cancel", "", "lib/_cancel.gif", "", 57, 15);
-      //$bb = new form_imagebutton("BackThread", "Back To Threads", "", "lib/_back.gif", "", 42, 15);
+      $pb = new form_imagebutton("SaveThread", "Save Thread", "", "$LIBDIR/img/_save.gif", "", 57, 15);
+      $cb = new form_imagebutton("CancelThread", "Cancel", "", "$LIBDIR/img/_cancel.gif", "", 57, 15);
+      //$bb = new form_imagebutton("BackThread", "Back To Threads", "", "$LIBDIR/img/_back.gif", "", 42, 15);
     }
 
     debugbr("error message: $this->error_msg");
@@ -1305,17 +1369,17 @@ class thread_msg extends forum_thread {
 
     $T->tr();
     $T->td("&nbsp;");
-    $T->td("Posted by $this->author on $this->date_posted");
+    $T->td("Posted by $this->author on $this->date_posted", "axmsgpostinfo");
     //$T->td_contentcss("font-size:9pt");
     $T->tr();
-    $T->td("Subject:&nbsp;");
+    $T->td("Subject:&nbsp;", "axforumform");
     /*$T->td_contentcss("font-size:9pt;
                        color: #FF6600;");*/
     $T->td_width("25%");
     $T->td_alignment("right");
     $T->td($ms->render());
     $T->tr();
-    $T->td("Text:&nbsp;");
+    $T->td("Text:&nbsp;", "axforumform");
     /*$T->td_contentcss("font-size:9pt;
                        color: #FF6600;");*/
     $T->td_width("25%");
@@ -1324,9 +1388,10 @@ class thread_msg extends forum_thread {
 
     // POST button
     $T->tr();
+    $T->td("&nbsp;");
     $T->td(/*$bb->render() . " " .*/ $cb->render() . " " . $pb->render());
-    $T->td_colspan(2);
-    $T->td_alignment("center");
+    //$T->td_colspan(2);
+    $T->td_alignment("left");
 
     $fidh = new form_hiddenfield("forum_id", $forum_id);
     $tidh = new form_hiddenfield("thread_id", $this->thread_id);
@@ -1346,7 +1411,7 @@ class thread_msg extends forum_thread {
 
   function edit_msg() {
     // displays the form objects for editing a message.
-    global $RESPONSE, $forum_id, $mode;
+    global $RESPONSE, $LIBDIR, $forum_id, $mode;
     global $quote;
 
     // set the non-entered fields for a message
@@ -1381,12 +1446,12 @@ class thread_msg extends forum_thread {
 
     $T->tr();
     $T->td("&nbsp;");
-    $T->td("EDIT MESSAGE / THREAD", "forumheadings");
+    $T->td("EDIT MESSAGE / THREAD", "axforumformheadings");
     /*$T->td_contentcss("font-size:12pt;
                        color: #FF6600;
                        font-weight: bold;");*/
-    $pb = new form_imagebutton("SaveMsg", "Save Msg", "", "lib/_save.gif", "", 57, 15);
-    $cb = new form_imagebutton("CancelMsg", "Cancel", "", "lib/_cancel.gif", "", 57, 15);
+    $pb = new form_imagebutton("SaveMsg", "Save Msg", "", "$LIBDIR/img/_save.gif", "", 57, 15);
+    $cb = new form_imagebutton("CancelMsg", "Cancel", "", "$LIBDIR/img/_cancel.gif", "", 57, 15);
 
     debugbr("error message: $this->error_msg");
     if ( trim($this->error_msg) != "" ) {
@@ -1401,17 +1466,17 @@ class thread_msg extends forum_thread {
 
     $T->tr();
     $T->td("&nbsp;");
-    $T->td("Posted by $this->author on $this->date_posted");
+    $T->td("Posted by $this->author on $this->date_posted", "axmsgpostinfo");
     //$T->td_contentcss("font-size:9pt");
     $T->tr();
-    $T->td("Subject:&nbsp;");
+    $T->td("Subject:&nbsp;", "axforumform");
     /*$T->td_contentcss("font-size:9pt;
                        color: #FF6600;");*/
     $T->td_width("25%");
     $T->td_alignment("right");
     $T->td($ms->render());
     $T->tr();
-    $T->td("Text:&nbsp;");
+    $T->td("Text:&nbsp;", "axforumform");
     /*$T->td_contentcss("font-size:9pt;
                        color: #FF6600;");*/
     $T->td_width("25%");
@@ -1420,9 +1485,10 @@ class thread_msg extends forum_thread {
 
     // POST button
     $T->tr();
+    $T->td("&nbsp;");
     $T->td($cb->render() . " " . $pb->render());
-    $T->td_colspan(2);
-    $T->td_alignment("center");
+    $T->td_colspan(1);
+    $T->td_alignment("left");
 
     $fidh = new form_hiddenfield("forum_id", $forum_id);
     $tidh = new form_hiddenfield("thread_id", $this->thread_id);
@@ -1441,4 +1507,4 @@ class thread_msg extends forum_thread {
   } // edit_msg
 } // class thread_msg
 // ----------------------------------------------------------------------
-?>
\ No newline at end of file
+?>
