@@ -57,7 +57,6 @@ $RESPONSE->body->add_script(
 * @return string The string with all layout content rendered into it
 */
 function render_layouts($s) {
-  $mytimer = new microtimer();
   $rs = $s;
   if (stristr($rs, "LAYOUTID=")) {
     preg_match_all("/<!--LAYOUTID=\"(.+)\"-->/i", $rs, $matches);
@@ -221,6 +220,10 @@ class layout extends RenderableObject {
       include_once("layout-editor-defs.php");
       $this->layouteditor = new layouteditor($this);
     }
+    else {
+      // Give it an up to date set of data..
+      $this->layouteditor->refresh($this);
+    }
   } // activate_editing
   // ....................................................................
   /**
@@ -290,7 +293,7 @@ class layout extends RenderableObject {
         }
       }
       else {
-        debugbr("default privilege settings apply");
+        debugbr("default privilege settings apply", DBG_DEBUG);
       }
       // Back-fill with all non-privileged groups
       $Gp = dbrecordset("SELECT * FROM ax_group");
