@@ -52,11 +52,18 @@ class layouteditor extends RenderableObject {
   * @param reference $layout A reference to the layout being edited
   */
   function layouteditor(&$layout) {
-    // Find out if there is an Editor group(s) override..
     $this->layout = $layout;
   } // layouteditor
   // ....................................................................
   /**
+  * Refresh the layout reference..
+  * @param reference $layout A reference to the layout being edited
+  */
+  function refresh(&$layout) {
+    $this->layout = $layout;
+  } // refresh
+  // ....................................................................
+  /**
   * Replicate the hosted layout as a new layout. Creates a brand new
   * layout in the database, with same data as this one. The end result
   * is that this current object becomes the new layout, and a duplicate
