@@ -660,6 +660,7 @@ function emailthem($eto, $eCc, $efrom, $esubject, $ebody, $emailformat="plain",
   if ($eCc != "") $headers .= "Cc: $eCc\n";
   $headers .= "Reply-To: $efrom\n";
   $headers .= "Errors-To: $efrom\n";
+  $headers .= "Return-Path: $efrom\n";
 
   switch ($emailformat) {
     case "html":
@@ -677,7 +678,20 @@ function emailthem($eto, $eCc, $efrom, $esubject, $ebody, $emailformat="plain",
   } // switch
 
   $headers .= "X-Mailer: PHP/" . phpversion();
-  mail($eto, $esubject, $ebody, $headers);
+
+  // The -f parameter sets who the mail is from, by setting the email
+  // address on the 'envelope' of the mail. This can only be done by a
+  // user 'trusted' by sendmail, so make sure the user the webserver
+  // runs as (eg. www-data) is marked as trusted in this way.
+  $sentok = mail(
+            $eto,
+            $esubject,
+            $ebody,
+            $headers,
+            "-f$efrom"
+            );
+  // Return status of send..
+  return $sentok;
 } // emailthem
 
 // -------------------------------------------------------------------------
