@@ -521,7 +521,7 @@ class menu extends StylableObject {
       $row = 0;
       $html .= "<span";
       if ($this->class != "") {
-        $html .= " class=\"$this->class\"";
+        $html .= " class=\"" . $this->class . "\"";
       }
       if ($this->style != "") {
         $html .= " style=\"$this->style\"";
