@@ -35,28 +35,25 @@ include_once("lockfile-defs.php");
 // DEFINITIONS & CONSTANTS
 // Condition types..
 
-/** Aggregate: all conditions */
-define("COND_ALL",      -1);
 /** Condition for a passed test */
 define("COND_OK",        0);
 /** Warning condition */
 define("COND_WARNING",   1);
-/** Error condition */
-define("COND_ERROR",     2);
-/** Fatal error condition */
-define("COND_FATAL",     3);
-/** Aggregate: no conditions */
-define("COND_NONE",    100);
+/** Critical error condition */
+define("COND_CRITICAL",  2);
 /** Condition is undefined */
-define("COND_UNKNOWN", 101);
+define("COND_UNKNOWN",  -1);
+/** Aggregate: no conditions */
+define("COND_NONE",     -2);
+/** Aggregate: all conditions */
+define("COND_ALL",      -3);
 
 /** Array of condition descriptions */
 $condition_desc = array(
-  COND_UNKNOWN => "UNKNOWN",
-  COND_OK      => "OK",
-  COND_WARNING => "WARNING",
-  COND_ERROR   => "ERROR",
-  COND_FATAL   => "FATAL"
+  COND_UNKNOWN  => "UNKNOWN",
+  COND_OK       => "OK",
+  COND_WARNING  => "WARNING",
+  COND_CRITICAL => "CRITICAL"
   );
 
 // ----------------------------------------------------------------------
@@ -74,8 +71,8 @@ class generic_monitor {
   var $type = "unspec";
   /** Current condition of this monitor */
   var $condition = COND_UNKNOWN;
-  /** Error condition to set, on failure. */
-  var $fail_condition = COND_ERROR;
+  /** Condition to set, on failure. */
+  var $fail_condition = COND_CRITICAL;
   /** Set of messages for email, per condition */
   var $report_msgs = array();
   /** Set of messages for SMS, per condition */
@@ -85,9 +82,14 @@ class generic_monitor {
   // ....................................................................
   /** Define a new generic monitor object. */
   function generic_monitor($type="") {
+    global $condition_desc;
     if ($type != "") {
       $this->type = $type;
     }
+    // Initialise all known messages to blank..
+    foreach ($condition_desc as $cond => $desc) {
+      $this->set_messages($cond, "");
+    }
   }
   // ....................................................................
   /** Set the error condition messages for email and SMS.
@@ -162,14 +164,22 @@ class generic_monitor {
   * @return string The monitor message which is to be reported via email
   */
   function reportmsg() {
-    return $this->report_msgs[$this->condition];
+    $msg = "";
+    if (isset($this->report_msgs[$this->condition])) {
+      $msg = $this->report_msgs[$this->condition];
+    }
+    return $msg;
   } // reportmsg
   // ....................................................................
   /** Return the sms text message for current condition
   * @return string The monitor message which is to be reported via SMS
   */
   function smstxtmsg() {
-    return $this->smstxt_msgs[$this->condition];
+    $msg = "";
+    if (isset($this->smstxt_msgs[$this->condition])) {
+      $msg = $this->smstxt_msgs[$this->condition];
+    }
+    return $msg;
   } // smstxtmsg
   // ....................................................................
   /** Make the check.
@@ -215,9 +225,6 @@ class exec_monitor extends generic_monitor {
     $this->execparms = implode(" ", $bits);
     $this->success_regex = $success_regex;
     $this->publish_output = $publish_output;
-
-    // Set the fail condition to COND_ERROR as a default..
-    $this->set_fail_condition(COND_ERROR);
   } // exec_monitor
   // ....................................................................
   /**
@@ -327,22 +334,19 @@ class file_monitor extends generic_monitor {
   var $warnsecs = 0;
   /** Seconds before error condition
       @access private */
-  var $errsecs = 0;
+  var $critsecs = 0;
   // ....................................................................
   /**
   * Define a new file check object.
   * @param string $filepath Path to file or directory to check
   * @param integer $warnmins Minutes file can be idle before warning issued
-  * @param integer $errmins Minutes file can be idle before error raised
+  * @param integer $critmins Minutes file can be idle before critical error raised
   */
-  function file_monitor($filepath, $warnmins, $errmins) {
+  function file_monitor($filepath, $warnmins, $critmins) {
     $this->generic_monitor("file");
     $this->filepath = $filepath;
     $this->warnsecs = $warnmins * 60;
-    $this->errsecs = $errmins * 60;
-
-    // Set the fail condition to COND_ERROR as a default..
-    $this->set_fail_condition(COND_ERROR);
+    $this->critsecs = $critmins * 60;
   } // file_monitor
   // ....................................................................
   /** Make the check on the time the file was last modified and if this
@@ -357,7 +361,7 @@ class file_monitor extends generic_monitor {
       $hours = floor($idlesecs / 3600);
       $mins  = floor(($idlesecs % 3600) / 60);
       $idletime = $hours . "hrs $mins" . "mins";
-      if ($idlesecs >= $this->warnsecs && $idlesecs < $this->errsecs) {
+      if ($idlesecs >= $this->warnsecs && $idlesecs < $this->critsecs) {
         $this->set_condition(COND_WARNING);
         $this->set_default_messages(
             COND_WARNING,
@@ -365,7 +369,7 @@ class file_monitor extends generic_monitor {
             "$this->filepath IDLE"
             );
       }
-      elseif ($idlesecs > $this->errsecs) {
+      elseif ($idlesecs > $this->critsecs) {
         $this->set_condition($this->fail_condition);
         $this->set_default_messages(
             $this->fail_condition,
@@ -396,19 +400,127 @@ class file_monitor extends generic_monitor {
 
 } // file_monitor class
 
+// ----------------------------------------------------------------------
+/**
+* A monitor class to check if a given process is running. This can be
+* achieved by consulting a pidfile, or by checking the process status
+* listing for the given process name (the default behaviour).
+* @package monitor
+*/
+class process_monitor extends generic_monitor {
+  // Public
+  // Private
+  /** Name of the process being monitored.
+      @access private */
+  var $procname = "";
+  /** Path to the PID file containing a process ID for the running process. Leave
+      this as nullstring to check using the $procname case-insensitively by searching the full process listing for the
+      process name.
+      @access private */
+  var $pidfile = "";
+  /** The 'ps' command to use for a specific process ID#. This allows override
+      of  the default, in cases of use on systems requiring differing path or options.
+      @access private */
+   var $ps_pid_cmd = "ps --no-headers -p";
+  /** The 'ps' command to use for an 'all processes list. This allows override
+      of the default, in cases of use on systems requiring differing path or options.
+      @access private */
+   var $ps_all_cmd = "ps ax";
+  // ....................................................................
+  /**
+  * Defines a new process monitoring object and provides matching info.
+  * @param string $procname Name of the process to search for using 'ps'.
+  * @param string $pidfile Path to PID file, or nullstring if matching on $procname.
+  * @param string $ps_all_cmd The 'ps' command to use for 'all processes' listing.
+  * @param string $ps_pid_cmd The 'ps' command to use for a specific process.
+  */
+  function process_monitor($procname, $pidfile="", $ps_all_cmd="", $ps_pid_cmd="") {
+    $this->generic_monitor("proc");
+    $this->procname = $procname;
+    $this->pidfile = $pidfile;
+    if ($ps_all_cmd != "") {
+      $this->ps_all_cmd = $ps_all_cmd;
+    }
+    if ($ps_pid_cmd != "") {
+      $this->ps_pid_cmd = $ps_pid_cmd;
+    }
+  } // file_monitor
+  // ....................................................................
+  /** Make the check on the time the file was last modified and if this
+  * is longer than this->warnsecs ago but less than this->errsecs then
+  * issue a warning. Otherwise if it is longer than this->errsecs ago
+  * then we issue an error message.
+  * @return integer Condition determined by this check
+  */
+  function check() {
+    if ($this->procname != "") {
+      $ps = "";
+      // Default is to match procname in process listing..
+      if ($this->pidfile == "") {
+        $ps = shell_exec("$this->ps_all_cmd");
+        if (stristr($ps, $this->procname) === false) {  
+          $this->set_condition($this->fail_condition);
+          $this->set_default_messages(
+              $this->fail_condition,
+              "Process ($this->procname) is not running.",
+              "Proc ($this->procname) not running."
+              );
+        }
+        else {
+          $this->set_condition(COND_OK);
+          $this->set_default_messages(
+              COND_OK,
+              "Process ($this->procname) is running.",
+              "Proc ($this->procname) ok."
+              );
+        }
+      }
+      // Search for specific PIDfile & process ID..
+      else {
+        if (file_exists($this->pidfile)) {
+          $pid = trim(shell_exec("cat $this->pidfile"));
+          if ($pid != "") {
+            $ps = shell_exec("$this->ps_pid_cmd $pid");
+          }
+          if ($ps == "") {
+            $this->set_condition($this->fail_condition);
+            $this->set_default_messages(
+                $this->fail_condition,
+                "Process $this->procname ($pid) is not running.",
+                "Proc $this->procname ($pid) dead."
+                );
+          }
+          else {
+            $this->set_condition(COND_OK);
+            $this->set_default_messages(
+                COND_OK,
+                "Process $this->procname ($pid) is running.",
+                "Proc $this->procname ($pid) ok."
+                );
+          }
+        }
+        else {
+          $this->set_condition($this->fail_condition);
+          $this->set_default_messages(
+              $this->fail_condition,
+              "Process $this->procname no pidfile ($this->pidfile).",
+              "Proc $this->procname no pidfile."
+              );
+        }
+      }
+    }
+    // Return condition..
+    return $this->condition;
+  } // check
+
+} // process_monitor class
+
 // ----------------------------------------------------------------------
 /**
 * A monitor class to check if Postgres is up and about. You need to
 * specify a database and a user (and if required, a password) which can
 * be use to test-connect to Postgres. Optionally you can specify the
 * host and port number if connection is over TCP.
-*
-* NOTE: The 'monitor' class which uses this class implements a rule
-*       which says that when a monitor (such as this one) returns a
-*       FATAL condition, then the checking process will die, having
-*       sent notifications out. If you don't want this to return the
-*       COND_FATAL condition on failure use the 'set_fail_condition()'
-*       method to set it to COND_ERROR.
 * @package monitor
 */
 class postgres_monitor extends generic_monitor {
@@ -448,10 +560,6 @@ class postgres_monitor extends generic_monitor {
     $this->password = $password;
     $this->host = $host;
     $this->port = $port;
-
-    // Set the error condition for failure to be fatal, since by
-    // default we consider a non-working database to be just that!
-    $this->set_fail_condition(COND_FATAL);
   } // postgres_monitor
   // ....................................................................
   /** Make the check, as to whether we can connect to the Postgres DB.
@@ -554,9 +662,6 @@ class lucene_monitor extends generic_monitor {
     // Abbreviated version of hostname for messages..
     $bits = explode(".", $this->luhost);
     $this->luhost_abbrev = $bits[0];
-
-    // Set the fail condition to COND_ERROR as a default..
-    $this->set_fail_condition(COND_ERROR);
   } // lucene_monitor
   // ....................................................................
   /** Make the check on Lucene by firing the query off and checking for
@@ -640,9 +745,6 @@ class diskspace_monitor extends generic_monitor {
     $this->fsdir = $fsdir;
     $this->warnspace = $warnspace;
     $this->minspace = $minspace;
-
-    // Set the fail condition to COND_ERROR as a default..
-    $this->set_fail_condition(COND_ERROR);
   }
   // ....................................................................
   /**
@@ -708,6 +810,11 @@ class monitor {
   var $emailfrom = "";
   /** Address to email SMS txt messages */
   var $emailpager = "";
+  /** Whether to emit a status message to stdout. If true the monitor will 
+   * emit the current status, plus the message associated with the highest
+   * priority (most severe) condition in the monitor. Format will be:
+   *  'CRITICAL: some message goes here'. */
+  var $emit_status = false;
   /** Monitor lockfile path */
   var $lockfilepath = "";
 
@@ -724,9 +831,11 @@ class monitor {
   /** True if we are locked via lockfile
       @access private */
   var $locked = false;
-  /** Monitor worst case condition
+  /** Monitor highest priority condition
       @access private */
   var $condition = COND_OK;
+  /** Monitor highest priority message */
+  var $message = "";
   /** Report staging for email
       @access private */
   var $reportmsg = "";
@@ -738,10 +847,14 @@ class monitor {
   var $email_condition_threshold = COND_WARNING;
   /** Threshold condition for paging
       @access private */
-  var $pager_condition_threshold = COND_ERROR;
+  var $pager_condition_threshold = COND_CRITICAL;
   /** The current Unix timestamp
       @access private */
   var $tinow;
+  /** Condition to stop on. If this condition is defined then we
+      stop checking monitors the first time it is raised.
+      @access private */
+  var $stop_on_condition = COND_NONE; 
   /** Schedule of named timeslots for this monitor
       @access private */
   var $schedule;
@@ -750,7 +863,8 @@ class monitor {
   var $monitors = array();
   // ....................................................................
   /**
-  * Create a new monitor object.
+  * Create a new monitor object. This is the container for all of the
+  * monitors which you can define and use to monitor a complete system.
   * @param string $name Name of this monitor instance (message prefix)
   * @param string $emailto Email address to send monitor messages to
   * @param string $emailfrom Email from-address for monitor messages
@@ -819,8 +933,18 @@ class monitor {
     $this->reportmsg = "";
     $this->smstxtmsg = "";
     $this->condition = COND_OK;
+    $this->message = "";
   } // clear
   // ....................................................................
+  /** Control the emission of status and status message associated with
+   * the most sever monitor error. The monitor defaults to not doing this
+   * so you should call this method without parameters to turn it on.
+   * @param boolean $mode If true then turn on status emission mode.
+   */
+  function set_emit_status($mode=true) {
+    $this->emit_status = $mode;
+  } // set_emit_status
+  // ....................................................................
   /**
   * Lock the monitor. This is a private method which tries to lock the
   * monitor using the lockfile assigned to it.
@@ -841,9 +965,9 @@ class monitor {
         case LCK_E_CREFAIL:
         case LCK_E_FROZEN:
         case LCK_E_READFAIL:
-          $lockmon->set_condition(COND_ERROR);
+          $lockmon->set_condition(COND_CRITICAL);
           $lockmon->set_default_messages(
-              COND_ERROR,
+              COND_CRITICAL,
               $LCK->errormsg(),
               $LCK->errormsg()
               );
@@ -893,6 +1017,15 @@ class monitor {
     $this->pager_condition_threshold = $pager_cond;
   }
   // ....................................................................
+  /** Set the condition to stop checking monitor on. If this is set to something
+   * other than COND_NONE, then the first time a monitor is raised to this
+   * condition the checking process is stopped.
+   * @param int $cond Condition to stop the checking process on.
+   */
+  function set_stop_on_condition($cond) {
+    $this->stop_on_condition = $cond;
+  } // set_stop_on_condition
+  // ....................................................................
   /**
   * Raise a condition. The single parameter to this method is a monitor
   * object which will have had its check() method called. This contains the
@@ -905,6 +1038,7 @@ class monitor {
     // Set overall condition, if escalated..
     if ($monitor->condition > $this->condition) {
       $this->condition = $monitor->condition;
+      $this->message = $monitor->reportmsg();
     }
 
     // Report content..
@@ -951,8 +1085,8 @@ class monitor {
   } // notify
   // ....................................................................
   /** Iterate through all our monitors, checking in each case. Each
-  * monitor will implement its own kind of checking and set its
-  * condition afterward.
+  * monitor will implement its own kind of checking and set its condition afterward.
+  * We also check to see if we have to abort monitor checking on a given monitor condition.
   */
   function check_all_monitors() {
     // Iterate through our monitors..
@@ -960,10 +1094,8 @@ class monitor {
       $mon->check();
       if (!in_array($mon->condition, $mon->suppressed_conditions)) {
         $this->raise_condition( $mon );
-        // Deal with fatal conditions in the time-honoured way..
-        if ($mon->condition == COND_FATAL) {
-          $this->notify();
-          die;
+        if ($this->stop_on_condition != COND_NONE && $mon->condition == $this->stop_on_condition) {
+          break;
         }
       }
     }
@@ -973,13 +1105,15 @@ class monitor {
   * Check all monitors. Just iterate through them and raise the conditions
   * contained in the reports each one returns. After collecting the
   * details, we notify anyone which needs to know. If any condition
-  * returned from a check is FATAL, then the rule is we stop processing
+  * returned from a check is CRITICAL, then the rule is we stop processing
   * any further checks. Processing is done in order of definition of the
   * monitors added, so put your critical ones first.
   * NOTE: This method always performs a lock() before processing all the
   * monitors, then performs an unlock() at the end.
   */
   function check() {
+    global $condition_desc;
+    
     // Process if we are not in a 'skip' timeslot..
     $timeslot = $this->schedule->timeslot($this->tinow);
     switch ($timeslot) {
@@ -989,14 +1123,11 @@ class monitor {
       case "warnings":
         $this->set_condition_thresholds(COND_WARN, COND_WARN);
         break;
-      case "errors":
-        $this->set_condition_thresholds(COND_ERROR, COND_ERROR);
-        break;
-      case "fatal":
-        $this->set_condition_thresholds(COND_FATAL, COND_FATAL);
+      case "critical":
+        $this->set_condition_thresholds(COND_CRITICAL, COND_CRITICAL);
         break;
       case "verbose":
-        $this->set_condition_thresholds(COND_ALL, COND_ERROR);
+        $this->set_condition_thresholds(COND_ALL, COND_CRITICAL);
         break;
       case "testing":
         $this->set_condition_thresholds(COND_ALL, COND_ALL);
@@ -1004,7 +1135,7 @@ class monitor {
     } // switch
 
     // Lock the monitor, if we are using a lockfile. If this
-    // fails then it is regarded as a fatal error..
+    // fails then it is regarded as a critical error..
     if ($this->use_lockfile) {
       if ($this->lock()) {
         $this->check_all_monitors();
@@ -1014,7 +1145,6 @@ class monitor {
       else {
         // Lock failed, notify them & die..
         $this->notify();
-        die;
       }
     }
     // If no lockfile, just do it..
@@ -1025,6 +1155,11 @@ class monitor {
     // Notify people who want it..
     $this->notify();
 
+    // Emit stuff if we have been asked to..
+    if ($this->emit_status) {
+      echo $condition_desc[$this->condition] . ": $this->message";
+    }
+
     // Provide return code for caller..
     return $this->condition;
   } // check
