@@ -428,6 +428,9 @@ class DB_dbfield extends dbfield {
   var $isarray = false;
   // ....................................................................
   function DB_dbfield(&$schema, $name, $num, $type, $defaultval="", $notnull=false, $ispkey=false, $isarray=false) {
+    // Strip out any postgres typecast..
+    $bits = explode("::", $defaultval);
+    $defaultval = $bits[0];    
     $this->dbfield($schema, $name, $num, $type, $defaultval, $notnull, $ispkey);
     $this->isarray = $isarray;
   }
@@ -970,11 +973,12 @@ class DB_dbtable extends dbtable {
 class DB_schema extends schema {
   // ....................................................................
   /**
-  * Create a schema (database) of given name. The name should be a
+  * Create a schema (database) of given name & type. The name should be a
   * valid existing database name that is currently connected.
+  * @param string $name Name of this particular database
   */
   function DB_schema($name) {
-    $this->schema($name);
+    $this->schema($name, "Postgresql");
   }
   // ....................................................................
   /**
@@ -1157,7 +1161,8 @@ class DB_schema extends schema {
       }
     }
     $this->set_dbversion( (float) $vstr );
-    debugbr("Postgres database version set to $this->database_version");
+    debugbr("$this->database_server version detection", DBG_DEBUG);
+    debugbr("database version set to $this->database_version", DBG_DEBUG);
     return $this->database_version;
   }
 
