@@ -98,6 +98,18 @@ class transaction {
     global $RESPONSE;
     $tok = false;
     if ($RESPONSE->db_backed && $this->open) {
+      // Try to commit the transaction now..
+      if (!$this->failed) {
+        if ($RESPONSE->datasource->commit()) {
+          if (debugging()) {
+            debugbr("TOK: transaction committed.", DBG_SQL);
+          }
+          $tok = true;
+        }
+        else {
+          $this->failed = true;
+        }
+      }
       // Deal with failed transactions..
       if ($this->failed) {
         $errmsg = "transaction failed";
@@ -109,14 +121,6 @@ class transaction {
           $this->rollback();
         }
       }
-      // Handle successful transactions..
-      else {
-        $RESPONSE->datasource->commit();
-        if (debugging()) {
-          debugbr("TOK: transaction committed.", DBG_SQL);
-        }
-        $tok = true;
-      }
       // Always end up with it closed..
       $this->open = false;
     }
@@ -856,6 +860,21 @@ class dbrecords extends dbrows {
   } // get_row_raw
   // ....................................................................
   /**
+  * Return whether the name field exists in the resultset, true or false.
+  * @param string $fieldname The name of the field to check existence of
+  * @return boolean True if the named field exists in the resultset.
+  */
+  function field_exists($fieldname) {
+    global $RESPONSE;
+    // Intercept any errant querying in standalone mode..
+    if (!$RESPONSE->db_backed) return false;
+    if ($this->rid) {
+      return isset($this->current_row[$fieldname]);
+    }
+    else return false;
+  } // field_exists
+  // ....................................................................
+  /**
   * Get field content
   * Return the field content from the current database array (row).
   * Does not provide ANY pre/post-processing.
@@ -1129,6 +1148,18 @@ function get_next_sequencevalue($sequencename, $table="", $column="") {
   return $seq->next_sequencevalue($table, $column);
 } // get_next_sequencevalue
 // ......................................................................
+/**
+* A wrapper to get the current sequence value from a named sequence..
+* @param string $sequencename Name of the sequence
+* @param string $column Name of the column sequence is on
+* @param string $table Name of the table column is on
+* @return integer The value of the current integer in this sequence
+*/
+function get_current_sequencevalue($sequencename, $table="", $column="") {
+  $seq = new dbseq($sequencename);
+  return $seq->current_sequencevalue($table, $column);
+} // get_current_sequencevalue
+// ......................................................................
 // TRANSACTION Functions
 /**
 * Start a DB transaction. Alias for begin_transaction()
@@ -1206,4 +1237,16 @@ function lock($tablelist, $mode) {
   global $RESPONSE;
   return $RESPONSE->datasource->lock($tablelist, $mode);
 } // lock
+
+// ----------------------------------------------------------------------
+// DATABASE SELECTION
+/**
+* Global function to set the selected database to a new database. All
+* subsequent queries will then act on that database.
+* @param string $db_name Name of database to select - nullstring for 'default'.
+*/
+function select_database($db_name="") {
+  global $RESPONSE;
+  return $RESPONSE->select_database($db_name);
+}
 ?>
\ No newline at end of file
