@@ -308,6 +308,8 @@ class response extends webpage {
   /** Array of DTD specifiers for this response. @see set_dtd()
       @access private */
   var $DTD;
+  /** Reponse timer */
+  var $timer;
   // ...................................................................
   /**
   * Constructor
@@ -400,8 +402,7 @@ class response extends webpage {
         $this->browser = BROWSER_NONE;
         $this->browser_version = "";
         // The site Domain and URL..
-        $this->http_host = trim(`hostname --fqdn`);
-        $this->site_url = "http://$this->http_host";
+        $this->set_http_host(trim(`hostname --fqdn`));
         $this->site_docroot = getcwd();
         // For debugging, set output mode..
         $this->debugger->debug_output(DBG_O_CLI);
@@ -412,8 +413,7 @@ class response extends webpage {
         $this->browser = BROWSER_PHONE;
         $this->browser_version = "";
         // The site Domain and URL..
-        $this->http_host = $HTTP_HOST;
-        $this->site_url = "http://$this->http_host";
+        $this->set_http_host($HTTP_HOST);
         $this->site_docroot = $DOCUMENT_ROOT;
         break;
 
@@ -469,8 +469,7 @@ class response extends webpage {
         }
 
         // The site Domain and URL..
-        $this->http_host = $HTTP_HOST;
-        $this->site_url = "http://$this->http_host";
+        $this->set_http_host($HTTP_HOST);
         $this->site_docroot = $DOCUMENT_ROOT;
         break;
 
@@ -478,8 +477,7 @@ class response extends webpage {
         $this->browser = BROWSER_NONE;
         $this->browser_version = "";
         // The site Domain and URL..
-        $this->http_host = $HTTP_HOST;
-        $this->site_url = "http://$this->http_host";
+        $this->set_http_host($HTTP_HOST);
         $this->site_docroot = $DOCUMENT_ROOT;
     } // switch
 
@@ -532,6 +530,25 @@ class response extends webpage {
     $this->auth_fail_redirect = "";
     $this->multilang = MULTILANG_DISABLED;
   } // initialise
+  // .....................................................................
+  /**
+  * Set the response timer up. Set it ticking.
+  * @param boolean $mode If true then enable the response timer.
+  */
+  function enable_response_timer($mode=false) {
+    if ($mode === true) {
+      // Create the timer and start it..
+      include_once("timer-defs.php");
+      $this->timer = new microtimer();
+      $this->timer->start();
+    }
+    else {
+      // Remove any existing timer..
+      if (isset($this->timer)) {
+        unset($this->timer);
+      }
+    }
+  } // enable_response_timer
   // ...................................................................
   /**
   * Determine the browser type
@@ -721,8 +738,8 @@ class response extends webpage {
     $this->webpage();
 
     // Map alternative fieldnames onto standard ones..
-    if (isset($user) && !isset($tbxUsername)) $tbxUsername = $user;
-    if (isset($pass) && !isset($tbxPassword)) $tbxPassword = $pass;
+    if (isset($user) && $user != "" && !isset($tbxUsername)) $tbxUsername = $user;
+    if (isset($pass) && $pass != "" && !isset($tbxPassword)) $tbxPassword = $pass;
 
     // Always disable buffering mode for command-line..
     if ($this->browser_type == BROWSER_TYPE_CLI) {
@@ -760,21 +777,20 @@ class response extends webpage {
       if ($this->auth_type == HTTP_AUTHENTICATION) {
         debugbr("HTTP Authentication", DBG_DEBUG);
         if (!isset($PHP_AUTH_USER)) {
-          debugbr("NOT Got PHP_AUTH_USER - sending HTTP auth headers", DBG_DEBUG);
+          debugbr("sending HTTP authentication headers", DBG_DEBUG);
           header("WWW-Authenticate: Basic realm=\"" . APP_NAME . "\"");
           header("HTTP/1.0 401 Unauthorized");
           return;
         }
         else {
           // Get the HTTP authentication variables..
-          debugbr("Got PHP_AUTH_USER '$PHP_AUTH_USER', PHP_AUTH_PS '$PHP_AUTH_PW'", DBG_DEBUG);
           if ($this->get_session_cookie()) {
-            debugbr("We already have a valid session..", DBG_DEBUG);
+            debugbr("already have a valid session..", DBG_DEBUG);
             if ($this->identify_user()
               && $this->userid == "guest"
               && strtolower($PHP_AUTH_USER != "guest")
             ) {
-              debugbr("But overriding guest session with supplied HTTP Auth login..", DBG_DEBUG);
+              debugbr("overriding guest session with supplied HTTP Auth login..", DBG_DEBUG);
               $tbxUsername = $PHP_AUTH_USER;
               if (isset($PHP_AUTH_PW)) $tbxPassword = $PHP_AUTH_PW;
               else $tbxPassword = "";
@@ -782,7 +798,7 @@ class response extends webpage {
           }
           else {
             // Transform it into our own kind of login sequence..
-            debugbr("Transforming it into our own kind of login..", DBG_DEBUG);
+            debugbr("morphing to Axyl login..", DBG_DEBUG);
             $tbxUsername = $PHP_AUTH_USER;
             if (isset($PHP_AUTH_PW)) $tbxPassword = $PHP_AUTH_PW;
             else $tbxPassword = "";
@@ -834,7 +850,9 @@ class response extends webpage {
               break;
 
             case AUTHFAIL_REDIRECT:
+              log_sys("AUTHFAIL_REDIRECT: user=$tbxUsername dest=$this->auth_fail_redirect");
               header("Location: $this->auth_fail_redirect");
+              exit;
               break;
 
             // AUTHFAIL_GUEST and friends..
@@ -842,7 +860,7 @@ class response extends webpage {
               if (isset($tbxUsername) && strtolower($tbxUsername) == "guest") {
                 // Failed guest login should not happen if the guest user
                 // exists and its 'enabled' flag is true..
-                $this->crash(401, "Guest logins are not permitted.");
+                $this->crash(401, "AUTHFAIL_GUEST: Guest logins are not permitted.");
               }
               else {
                 // Unset everything they might be logging in with, so that
@@ -861,7 +879,7 @@ class response extends webpage {
         // Otherwise we failed authentication, but the user was
         // valid - a very strange state of affairs..!
         else {
-          debugbr("user valid but not auth! userid='$this->userid'", DBG_DEBUG);
+          debugbr("user '$this->userid' valid but failed authentication", DBG_DEBUG);
           if ($this->authfail_option != AUTHFAIL_SILENT) {
             $this->crash(500, "No session!");
           }
@@ -877,7 +895,15 @@ class response extends webpage {
     } while (!$logged_in && $retries > 0);
 
     // If login failed, then we have no options left..
-    if (!$logged_in) {
+    if ($logged_in) {
+      if ($this->login_type == LOGIN_BY_PASSWD) {
+        if ($this->password_expired() && $this->requested != "/axyl-login.php") {
+          header("Location: /axyl-login.php");
+          exit;
+        }
+      }
+    }
+    else {
       if ($this->authfail_option != AUTHFAIL_SILENT) {
         $this->crash(401);
       }
@@ -1220,6 +1246,20 @@ class response extends webpage {
     $this->auth_fail_option = $option;
     $this->auth_fail_redirect = $redirect;
   } // on_authentication_fail
+  
+  // ...................................................................
+  /**
+   * Set the hostname of the machine serving this Axyl website. This is
+   * usually the same as that in the global $HTTP_HOST variable.
+  * @param string $http_host The hostname of the machine serving this website
+   */
+  function set_http_host($http_host="") {
+    if ($http_host != "") {
+      $this->http_host = $http_host;
+      $this->site_url  = "http://$this->http_host";
+    }
+  } // set_http_host
+  
   // ...................................................................
   /**
   * Add database
@@ -1231,14 +1271,22 @@ class response extends webpage {
   * @param string  $passwd    The password the user can access the database with
   * @param string  $host      The hostname of the machine running the database (TCP/IP)
   * @param integer $port      The port number of the database server
+  * @param string  $enc       The database character encoding (eg. 'US_ASCII', 'UNICODE')
+  * @param string  $datestyle The database date style (eg. 'ISO')
   * @param boolean $default   True if the database is the default database
   */
-  function add_database($dbtype, $name, $user="", $passwd="", $host="", $port="", $default=false) {
+  function add_database(
+          $dbtype,
+          $name, $user="", $passwd="",
+          $host="", $port="",
+          $enc="UNICODE", $datestyle="ISO",
+          $default=false)
+  {
     if ($this->db_backed) {
       if (!isset($this->datasource)) {
         $this->datasource = new datasources();
       }
-      $this->datasource->add_database($dbtype, $name, $user, $passwd, $host, $port, $default);
+      $this->datasource->add_database($dbtype, $name, $user, $passwd, $host, $port, $enc, $datestyle, $default);
     }
   } // add_database
   // ...................................................................
@@ -1374,13 +1422,13 @@ class response extends webpage {
     // For the system log..
     $logmsg = APP_PREFIX . " CRASH: ";
     if ($msg != "") $logmsg .= $msg;
-    else $logmsg = "(no message)";
+    else $logmsg = "(no reason provided)";
     if ($code) $logmsg .= " ($code)";
-    error_log(APP_PREFIX . " CRASH: $msg.");
+    error_log(APP_PREFIX . " CRASH: $logmsg");
     // For the user..
-    if ($code || $msg != "") {
+    if ($code !== false || $msg != "") {
       $umsg = "";
-      if ($code) $umsg .= HTTPError($code) . " ";
+      if ($code !== false) $umsg .= HTTPError($code) . " ";
       if ($msg != "") $umsg .= $msg;
       die($umsg);
     }
@@ -1416,10 +1464,21 @@ if (file_exists("$DOCUMENT_ROOT/application.xml") && isset($application) && $app
       foreach ($setting->parameters as $parameter) {
         $parms[] = $parameter->get_decodedvalue();
       }
-      // Set the 'default=true' parameter for first database..
-      if ($setting->name == "database" && $firstDB) {
-        $parms[] = true;
-        $firstDB = false;
+      if ($setting->name == "database") {
+        // Make sure number of database params is right..
+        if (count($parms) < 8) {
+          $RESPONSE->crash(403,
+                     "Database '" . $parms[1] . "': Wrong number of database parameters "
+                   . "for this version of Axyl. Check your 'application.xml' schema is "
+                   . "up to date, and run the latest version of control-panel.php, if "
+                   . "necessary, to update it."
+                   );
+        }
+        // Set the 'default=true' parameter for first database..
+        if ($firstDB) {
+          $parms[] = true;
+          $firstDB = false;
+        }
       }
       // Apply the RESPONSE setting..
       call_user_method_array($methodname, $RESPONSE, $parms);
@@ -1532,6 +1591,5 @@ if (file_exists("$DOCUMENT_ROOT/application.xml") && isset($application) && $app
     }
   } // microsites enabled
 }
-
 // -----------------------------------------------------------------------
 ?>
\ No newline at end of file
