@@ -61,7 +61,7 @@ class SchemaObject {
   */
   function SchemaObject($schema, $name) {
     $this->schema = $schema;
-    $this->name = strtolower($name);
+    $this->name = $name;
   }
 } // class SchemaObject
 
@@ -794,6 +794,35 @@ class dbtable extends SchemaObject {
     return $labelfield;
   } // getlabelfield
   // ....................................................................
+  /**
+  * Returns a candidate ordering field name according to some fairly simple
+  * heuristics. If nothing is found then a labelfield is used as fallback.
+  * @param $pattern Extra pattern to use in matching likely fieldnames
+  */
+  function getorderfield($pattern="") {
+    $keyfields = $this->getkeyfieldnames();
+    $patts = array();
+    if ($pattern != "") {
+      $patts[] = $pattern;
+    }
+    $patts[] = "order";
+    foreach ($patts as $patt) {
+      foreach ($this->fields as $field) {
+        if (!in_array($field->name, $keyfields)
+          && preg_match("/$patt/i", $field->name)) {
+          $orderfield = $field->name;
+          $done = true;
+          break;
+        }
+      }
+    }
+    // Fall back if necessary..
+    if ($orderfield == "") {
+      $orderfield = $this->getlabelfield();
+    }
+    return $orderfield;
+  } // getorderfield
+  // ....................................................................
   /** Returns field object of given name */
   function getfield($name) {
     return $this->fields[$name];
@@ -913,6 +942,7 @@ class dbtable extends SchemaObject {
 * @package database
 */
 class schema extends SchemaObject {
+  var $database_server = "Generic";
   var $database_version = 0;
   var $tables = array();
   var $sequences = array();
@@ -925,9 +955,12 @@ class schema extends SchemaObject {
   * Create a schema (database) of given name. The name should be a
   * valid existing database name that is currently connected. It will
   * be selected to ensure the correct data is obtained.
+  * @param string $name Name of this particular database
+  * @param string $dbserver Database server, eg. 'Postgresql', or 'Oracle' 
   */
-  function schema($name) {
+  function schema($name, $dbserver="Generic") {
     $this->name = $name;
+    $this->database_server = $dbserver;
     $this->getversion();
   }
   // ....................................................................
@@ -964,7 +997,6 @@ class schema extends SchemaObject {
   * for a specific table, without having to endure the overhead of reading
   * all of the database schema metadata to get it.
   * Override this method for your specific database type.
-  *
   * @param string $tablename Name of the table to acquire schema of
   */
   function getschema_table($tablename) {
