@@ -140,6 +140,8 @@ class session extends user {
   var $logins_exceeded_redirect = "";
   /** Login type for this session */
   var $login_type = LOGIN_BY_PASSWD;
+  /** Whether we are tracking session logins */
+  var $session_track_logins = true;
   // .....................................................................
   /**
   * Constructor
@@ -181,16 +183,18 @@ class session extends user {
     // Access to the vars..
     global $tbxUsername, $user; // Userid textbox fieldname submitted from a form
     global $tbxPassword, $pass; // Password textbox fieldname submitted from a form
+    global $chkRememberMe;      // Checkbox specific user request for extended cookie life
     global $tbxLogoff;          // Logoff hidden field sent from a form
     global $authid;             // Authorisation code (MD5) from form or URL
     global $REMOTE_ADDR;        // IP address of remote browser/client
 
     // Map alternative fieldnames onto standard ones..
-    if (isset($user) && !isset($tbxUsername)) $tbxUsername = $user;
-    if (isset($pass) && !isset($tbxPassword)) $tbxPassword = $pass;
+    if (isset($user) && $user != "" && !isset($tbxUsername)) $tbxUsername = $user;
+    if (isset($pass) && $pass != "" && !isset($tbxPassword)) $tbxPassword = $pass;
 
     // Initialise some variables..
     $this->session_clear();
+    $this->user();
 
     // If no database we are not tracking sessions..
     if (!$this->db_backed) return true;
@@ -209,7 +213,7 @@ class session extends user {
       || (isset($authid))
     ) {
       // Clear any existing session..
-      debugbr("authorisation detected, clearing session");
+      debugbr("authorisation detected, clearing session", DBG_DEBUG);
       $session_id = false;
       $this->session_clear();
     }
@@ -217,12 +221,12 @@ class session extends user {
     // EXISTING SESSION RECOVERY
     // If we still have a session id, then we try recovery..
     if ($session_id) {
-      debugbr("session id detected.");
+      debugbr("session id detected.", DBG_DEBUG);
       if ($this->recover($session_id)) {
         // Check if they want to logoff..
-        debugbr("recovered session: '$this->session_id'");
-        if (isset($tbxLogoff) && $tbxLogoff == "Logoff") {
-          debugbr("logging off, deleting session");
+        debugbr("recovered session: '$this->session_id'", DBG_DEBUG);
+        if (isset($tbxLogoff) && strcasecmp($tbxLogoff, "logoff") == 0) {
+          debugbr("logging off, deleting session", DBG_DEBUG);
           $this->session_delete();
         }
         else {
@@ -230,14 +234,14 @@ class session extends user {
           // this case we check for a possible IP login, so that these
           // users don't get marooned in a guest login session..
           if ($this->login_type == LOGIN_BY_GUEST) {
-            debugbr("guest recovered: checking for IP authentication..");
+            debugbr("guest recovered: checking for IP authentication..", DBG_DEBUG);
             $login_type = $this->authenticate_ipaddress($REMOTE_ADDR);
             if ($login_type != LOGIN_UNKNOWN) {
               $this->session_create($login_type);
             }
             else {
               // Keep the original guest authentication..
-              debugbr("falling back to guest");
+              debugbr("falling back to guest", DBG_DEBUG);
               $this->valid = true;
               $this->authenticated = true;
             }
@@ -252,11 +256,11 @@ class session extends user {
     // and log them in..
     if (!$this->session_id) {
       $authenticated = false;
-      debugbr("no session, looking to create new one");
+      debugbr("no session, looking to create new one", DBG_DEBUG);
 
       // AUTH CODE AUTHENTICATION..
       if (!$authenticated && isset($authid)) {
-        debugbr("trying authid authentication..");
+        debugbr("trying authid authentication..", DBG_DEBUG);
         $login_type = $this->authenticate_authid($authid);
         if ($login_type != LOGIN_UNKNOWN) {
           $this->session_create($login_type);
@@ -266,7 +270,7 @@ class session extends user {
 
       // IP ADDRESS AUTHENTICATION..
       if (!$authenticated && !isset($tbxUsername)) {
-        debugbr("trying IP authentication..");
+        debugbr("trying IP authentication..", DBG_DEBUG);
         $login_type = $this->authenticate_ipaddress($REMOTE_ADDR);
         if ($login_type != LOGIN_UNKNOWN) {
           $this->session_create($login_type);
@@ -281,68 +285,59 @@ class session extends user {
       if (!$authenticated) {
         // Default to guest, if no login supplied..
         if (!isset($tbxUsername)) {
-          debugbr("username not set, falling back to guest");
+          debugbr("username not set, falling back to guest", DBG_DEBUG);
           $tbxUsername = "guest";
         }
         if (!isset($tbxPassword)) $tbxPassword = "";
         $tbxUsername = trim($tbxUsername);
 
-        debugbr("user=$tbxUsername, passwd=$tbxPassword");
-
         // Authenticate the login attempt. If successful, this
         // populates the user and usergroups information..
         $login_type = $this->authenticate_userid($tbxUsername, $tbxPassword);
         if ($login_type != LOGIN_UNKNOWN) {
-          $authenticated = true;
+          // Check for user request to extend cookie life..
+          if (isset($chkRememberMe)) {
+            debugbr("forcing session lifetime to forever", DBG_DEBUG);
+            $this->set_lifetime(SESS_FOREVER);
+          }
           $this->session_create($login_type);
+          $authenticated = true;
         }
       }
     } // new session
 
     // Return status..
     if (debugging() && $this->session_valid()) {
-      debug("session type: ");
+      debug("session type: ", DBG_DEBUG);
       switch ($this->login_type) {
         case LOGIN_BY_GUEST:
-          debugbr("guest");
+          debugbr("guest", DBG_DEBUG);
           break;
         case LOGIN_BY_IP:
-          debugbr("authorised by IP address");
+          debugbr("authorised by IP address", DBG_DEBUG);
           break;
         case LOGIN_BY_PASSWD:
-          debugbr("authorised by userid/password");
+          debugbr("authorised by userid/password", DBG_DEBUG);
           break;
         case LOGIN_BY_AUTHCODE:
-          debugbr("authorised by auth code");
+          debugbr("authorised by auth code", DBG_DEBUG);
           break;
         default:
-          debugbr("unknown");
+          debugbr("unknown", DBG_DEBUG);
       } // switch
     }
     return $this->session_valid();
 
     debug_trace();
   } // identify_user
-  // .....................................................................
-  /**
-  * Setup session parameters
-  * Here is where we set up our session to suit..
-  * @access private
-  */
-  function set_sessionparms() {
-    global $RESPONSE;
-    debug_trace($this);
-    $RESPONSE->datasource->set_datestyle("ISO");
-    $RESPONSE->datasource->set_char_encoding("UTF-8");
-    debug_trace();
-  } // set_sessionparms
   // ....................................................................
   /**
   * Check if we should bump our login count.
   * @access private
   */
   function track_logins() {
-    if ($this->login_type != LOGIN_BY_GUEST) {
+    if ($this->login_type != LOGIN_BY_GUEST && $this->session_track_logins === true) {
+      debugbr("session login tracking is enabled", DBG_DEBUG);
       debug_trace($this);
       // Timestamp of now...
       $tinow = time();
@@ -371,6 +366,9 @@ class session extends user {
       }
       debug_trace();
     }
+    else {
+      debugbr("session login tracking is disabled", DBG_DEBUG);
+    }
   } // track_logins
   // ...................................................................
   /**
@@ -408,7 +406,7 @@ class session extends user {
     debug_trace($this);
     // Check for multiple login limit restriction..
     if ($this->limit_logins > 0) {
-      debugbr("checking login limit of $this->limit_logins.");
+      debugbr("checking login limit of $this->limit_logins.", DBG_DEBUG);
       $q  = "SELECT session_id";
       $q .= "  FROM ax_wwwsession";
       $q .= " WHERE user_id='" . addslashes($this->userid) . "'";
@@ -418,7 +416,7 @@ class session extends user {
       // adding as part of this process shortly..
       $excesslogins = 1 + $loginQ->rowcount - $this->limit_logins;
       if ($excesslogins > 0) {
-        debugbr("oops: " . ($loginQ->rowcount) . " logins already; $excesslogins too many.");
+        debugbr("oops: " . ($loginQ->rowcount) . " logins already; $excesslogins too many.", DBG_DEBUG);
         switch ($this->logins_exceeded_option) {
           case SESS_ALLOW:
             // Do nothing. This is for when the developer
@@ -470,7 +468,7 @@ class session extends user {
         } // switch
       }
       else {
-        debugbr("no excess logins.");
+        debugbr("no excess logins.", DBG_DEBUG);
       }
     }
     debug_trace();
@@ -489,27 +487,31 @@ class session extends user {
       if ($session->hasdata) {
         // Find user record and check enabled..
         $this->user($session->field("user_id"));
-        if ($this->enabled) {
-          $this->session_id = $session_id;
-          $this->userid = $session->field("user_id");
-          $this->session_record = $session->current_row;
-          $this->login_type = $session->field("login_type");
-          $this->last_logintime = datetime_to_timestamp($session->field("login_datetime"));
-          // This writes login total to the uuser record, and
-          // login datetime to the wwwsession record..
-          $this->track_logins();
-          // This sets the database session environment up..
-          $this->set_sessionparms();
-          debugbr("found session record.");
+        if (!$this->locked) {
+          if ($this->enabled) {
+            $this->session_id = $session_id;
+            $this->userid = $session->field("user_id");
+            $this->session_record = $session->current_row;
+            $this->login_type = $session->field("login_type");
+            $this->last_logintime = datetime_to_timestamp($session->field("login_datetime"));
+            // This writes login total to the uuser record, and
+            // login datetime to the wwwsession record..
+            $this->track_logins();
+            debugbr("found session record.", DBG_DEBUG);
+          }
+          else {
+            debugbr("session rejected: user '" . $session->field("user_id") . "' not enabled", DBG_DEBUG);
+            $this->valid = false;
+          }
         }
         else {
-          debugbr("session rejected: user '" . $session->field("user_id") . "' no longer enabled");
+          debugbr("session rejected: '" . $session->field("user_id") . "' account is locked", DBG_DEBUG);
           $this->valid = false;
         }
       }
       else {
         // Invalidate session and clear cookie..
-        debugbr("no valid session record found: clearing session data and cookie.");
+        debugbr("no valid session record found: clearing session data and cookie.", DBG_DEBUG);
         $this->session_clear();
         $this->delete_cookie();
       }
@@ -532,31 +534,39 @@ class session extends user {
       || $RESPONSE->browser_type == BROWSER_TYPE_HTML
       || $RESPONSE->browser_type == BROWSER_TYPE_XHTML
     ) {
-      if (!$expires) {
+      if ($expires === false) {
+        debug("cookie lifetime: ", DBG_DEBUG);
         if ($this->lifetime == SESS_BROWSER_LIFETIME
         || ($this->guest_browser_lifetime && $this->userid == "guest")
         ) {
           // Cookie lasts for browser lifetime
-          debugbr("cookie lifetime: browser");
+          debugbr("until browser closed", DBG_DEBUG);
           $expires = 0;
         }
         else {
           // Cookie lasts for given number of seconds..
           $expires = time() + $this->lifetime;
-          debugbr("cookie lifetime: $this->lifetime secs");
+          switch ($this->lifetime) {
+            case SESS_FOREVER:
+              debugbr("forever", DBG_DEBUG);
+              break;
+            default:
+              debugbr("$this->lifetime secs", DBG_DEBUG);
+              break;
+          } // switch
         }
       }
       if (isset($RESPONSE) && $RESPONSE->browser == BROWSER_NETSCAPE) {
-        debugbr("Setting Netscape cookie ".$this->cookiename.": $content, $expires");
+        debugbr("Setting Netscape cookie ".$this->cookiename.": $content, $expires", DBG_DEBUG);
         setcookie($this->cookiename, $content, $expires);
       }
       else {
         if ($_SERVER["SERVER_ADDR"] == "127.0.0.1") {
-          debugbr("Server running on localhost - setting cookie ".$this->cookiename.": $content, $expires, /");
+          debugbr("Server running on localhost - setting cookie ".$this->cookiename.": $content, $expires, /", DBG_DEBUG);
           setcookie($this->cookiename, $content, $expires, "/");
         }
         else {
-          debugbr("Setting cookie ".$this->cookiename.": $content, $expires, /, ".$this->http_host);
+          debugbr("Setting cookie ".$this->cookiename.": $content, $expires, /, ".$this->http_host, DBG_DEBUG);
           setcookie($this->cookiename, $content, $expires, "/", $this->http_host);
         }
       }
@@ -569,7 +579,7 @@ class session extends user {
   */
   function delete_cookie() {
     global $RESPONSE;
-    debugbr("Expiring cookie ".$this->cookiename);
+    debugbr("Expiring cookie ".$this->cookiename, DBG_DEBUG);
     if (!isset($RESPONSE)
       || $RESPONSE->browser_type == BROWSER_TYPE_HTML
       || $RESPONSE->browser_type == BROWSER_TYPE_XHTML
@@ -603,10 +613,16 @@ class session extends user {
   } // set_lifetime
   // ...................................................................
   /**
-  * Set session cookie name
+  * Set session cookie name. This method protects against silliness
+  * by detecting nullstring cookienames, and re-defining them to a
+  * default name based on the application prefix. Null cookienames
+  * are a very bad idea all around.
   * @param string $name Cookie name to use for session ID
   */
   function set_cookiename($name="session_id") {
+    if ($name == "") {
+      $name = APP_PREFIX . "_session_id";
+    }
     $this->cookiename = $name;
   } // set_cookiename
   // ...................................................................
@@ -619,28 +635,42 @@ class session extends user {
   function set_guest_browser_lifetime($guest_browser_lifetime=false) {
     $this->guest_browser_lifetime = $guest_browser_lifetime;
   } // set_guest_browser_lifetime
+  // ...................................................................
+  /**
+  * Set session track logins flag
+  * If set True this causes the session logins for this site to be tracked for
+  * each user. This amounts to an extra DB update of a login count field.
+  * @param bool $session_track_logins True if we should track all user logins
+  */
+  function set_session_track_logins($session_track_logins=false) {
+    $this->session_track_logins = $session_track_logins;
+  } // session_track_logins
   // .....................................................................
   /**
   * Create new session
   * Make a brand new session for the user.
   * @param integer $logintype Type of login for this session
   */
-  function session_create($logintype=LOGIN_BY_PASSWD) {
+  function session_create($logintype=LOGIN_BY_PASSWD) {   
     debug_trace($this);
 
     // Check for any excess sessions first..
     $this->check_excess_sessions();
 
     // Get next session key, and create session..
-    $this->set_sessionparms();
 
     // Generate a unique session handle..
     $this->session_id = md5(uniqid(rand(),1));
 
     // Initialise the login detail..
     $this->login_type = $logintype;
-    $this->last_logintime = time() - SESS_FOREVER;
-
+    $this->last_logintime = time();
+    // If we are tracking logins, and it's a real user, then we set the
+    // login datetime far enough back for the track_logins() method to act..
+    if ($this->session_track_logins && $this->login_type != LOGIN_BY_GUEST) {
+      $this->last_logintime -= SESS_FOREVER;
+    }
+    
     // Create the new session..
     $ugroups = "";
     if (isset($this->user_groups)) {
@@ -651,13 +681,7 @@ class session extends user {
     $wwwQ->set("user_id",        $this->userid);
     $wwwQ->set("user_groups",    $ugroups);
     $wwwQ->set("login_type",     $logintype);
-
-    // Non-guests get initial login datetime set very early so
-    // that track_logins() will increment the login counter. Guests
-    // will always get the database default of 'now'..
-    if ($this->login_type != LOGIN_BY_GUEST) {
-      $wwwQ->set("login_datetime", timestamp_to_datetime($this->last_logintime));
-    }
+    $wwwQ->set("login_datetime", timestamp_to_datetime($this->last_logintime));
 
     // Create the record..
     $wwwQ->execute();
