@@ -378,6 +378,15 @@ class webstream extends session {
       default:
         echo $this->content;
     } // switch
+    
+    // Log timer results, if enabled..
+    if (isset($this->timer)) {
+      log_sys("axyl response logging: "
+            . "user=" . $this->userid . " "
+            . "page=" . $this->requested . " "
+            . "time=" . $this->timer->formatted_millisecs() . "ms"
+            );
+    }
   } // send_to_browser
   // .....................................................................
   /**
