@@ -209,6 +209,36 @@ function create_new_field($tablename, $fieldname, $fieldtype) {
   return $res;
 } // create_new_field
 
+// ----------------------------------------------------------------------
+// Check we are root first of all..
+$uid = shell_exec("id -u");
+if ($uid != 0) {
+  abort("You must be root to run this script.");
+}
+
+// ----------------------------------------------------------------------
+// Get current Axyl installation version..
+$AXYL_VERSION = "";
+$VER_FILE = "/etc/axyl/axyl.version";
+$verf = new inputfile($VER_FILE);
+if ($verf->opened) {
+  $verf->readall();
+  $verf->closefile();
+  $AXYL_VERSION = trim($verf->content);  
+}
+
+if ($AXYL_VERSION != "") {
+  logit("Axyl installation: $AXYL_VERSION");
+}
+else {
+  abort(
+    "Axyl installation version was not found.\n"
+  . "This probably means that /etc/axyl/axyl.version does not exist, which\n"
+  . "in turn probably means you have an old version of the Axyl system\n"
+  . "and should take this opportunity to upgrade to the latest."
+  );
+}
+
 // ----------------------------------------------------------------------
 // Announce..
 echo "Important: Please do not run this script on an Axyl website without\n"
@@ -225,13 +255,6 @@ if ($ans != "y" && $ans != "Y") {
 }
 
 // ----------------------------------------------------------------------
-
-// Check we are root..
-$uid = shell_exec("id -u");
-if ($uid != 0) {
-  abort("You must be root to run this script.");
-}
-
 // Clear filesyste, stat cache..
 clearstatcache();
 
@@ -309,6 +332,7 @@ $AXYL_DATA = "";
 $LUCENE_PORT = 0;
 $LUCENE_INSTALLED = false;
 
+// Axyl configuration settings..
 $CONF_FILE = "/etc/axyl/axyl.conf";
 $conf = new inputfile($CONF_FILE);
 if ($conf->opened) {
@@ -450,12 +474,13 @@ if (`grep $WWWADMIN /etc/group | cut -d : -f 1` == "") {
 }
 
 echo "\nPlease list the Apache virtual host ServerNames, each separated by\n";
-echo "a space which will be serving this website. If necessary, go and\n";
-echo "have a look in your Apache config files now. This script will have\n";
-echo "a go at suggesting one, but it may get it wrong, or you might have\n";
-echo "more than one. Don't bother with ServerAlias's. List each ServerName\n";
-echo "which identifies a unique Virtual Host entry for this website.\n";
-echo "NB: enter 'none' to force no SeverNames specified.\n";
+echo "a space. A ServerName is a domain that your website will be served as\n";
+echo "eg. www.foo.com. If necessary, go and have a look in your Apache config\n";
+echo "files now.\n";
+echo "This script will have a go at suggesting one, but it may get it wrong,\n";
+echo "or you might have more than one. Don't bother with ServerAlias's. List\n";
+echo "each ServerName which identifies a unique Virtual Host entry for this\n";
+echo "website. [NB: enter 'none' to force no ServerNames specified.]\n";
 $VHSERVERNAMES = "";
 $APACHECONF = "$APACHE_CONFDIR/httpd.conf";
 if (file_exists($APACHECONF)) {
@@ -477,7 +502,7 @@ if (file_exists($APACHECONF)) {
     }
   }
 }
-echo "Website virtual host ServerNames? [$VHSERVERNAMES] :";
+echo "Virtualhost ServerNames that this website is served as? [$VHSERVERNAMES] :";
 $ans = rtrim(fgets($FH, 256));
 if ($ans != "") $VHSERVERNAMES = $ans;
 if ($ans == "none") $VHSERVERNAMES = "";
@@ -486,6 +511,7 @@ if ($ans == "none") $VHSERVERNAMES = "";
 // REPORT STATUS
 logit("\nINITIAL STATUS:");
 $WWW_PATH = getcwd();
+logit("Axyl Installation is version $AXYL_VERSION");
 logit("the website root directory is: '$WWW_PATH'");
 logit("website is served as: $VHSERVERNAMES");
 $msg = "local website Axyl lib is found in: '$LIBDIR'";
@@ -535,6 +561,7 @@ logit("\nUPDATING..");
 // DATABASE UPGRADE
 logit("Axyl database upgrade..");
 // Create axyl_core database from latest schema..
+logit(" ++ axyl core database..");
 $curdb = $RESPONSE->datasource->database[ $RESPONSE->datasource->db_name_default ];
 
 // If Axyl core DB already exists, drop it..
@@ -554,37 +581,142 @@ $diditwork = exec_pg_command("psql -d axyl_core", $curdb->user, $curdb->host, $c
 logit(" -- created latest axyl_core database");
 
 // Apply these specific customisations..
-logit(" -- ax_block 'columns' to 'cols' rename..");
+logit(" ++ ax_control table..");
+$hascontrol = false;
+$q = "SELECT relname FROM pg_class WHERE relname='ax_control'";
+$controltable = dbrecordset($q);
+if ($controltable->hasdata) {
+  logit(" -- ax_control table is present..");
+  $hascontrol = true;
+  // Check control table structure..
+  $q  = "SELECT pga.attname as fieldname";
+  $q .= "  FROM pg_class pgc,pg_attribute pga";
+  $q .= " WHERE pgc.relname='ax_control'";
+  $q .= "   AND pga.attrelid=pgc.oid";
+  $q .= "   AND pga.attname='site_axyl_version'";
+  $chkcontrol = dbrecordset($q);
+  if ($chkcontrol->hasdata) {
+    logit(" -- updating ax_control record..");
+    // Update control record..
+    $upcontrol = new dbupdte("ax_control");
+    $upcontrol->set("app_prefix", "'" . APP_PREFIX . "'");
+    $upcontrol->set("site_docroot", "'$WWW_PATH'");
+    $chkver = dbrecordset("SELECT * FROM ax_control");
+    // Only update the version if not there..
+    if ($chkver->field("site_axyl_version") == "") {
+      logit(" -- updating null ax_control version to $AXYL_VERSION");
+      $upcontrol->set("site_axyl_version", '$AXYL_VERSION');
+    }
+    else {
+      logit(" -- retaining ax_control version as " . $chkver->field("site_axyl_version"));
+    }
+    if (!$upcontrol->execute()) {
+      logit(" -- ax_control update FAILED!");
+    }    
+  }
+  else {
+    logit(" -- dropping invalid ax_control table");
+    if (dbcommand("DROP TABLE ax_control")) {
+      $hascontrol = false;
+    }
+    else {
+      logit(" -- drop of ax_control FAILED!");
+    }
+  }
+}
+if (!$hascontrol) {
+  logit(" -- creating the ax_control table..");
+  $q  = "create table ax_control (";
+  $q .= " app_prefix text,";
+  $q .= " site_axyl_version text,";
+  $q .= " site_docroot text";
+  $q .= ");";
+  $res = dbcommand($q);
+  if ($res) {
+    logit(" -- inserting ax_control record..");
+    $q  = "INSERT INTO ax_control (app_prefix,site_axyl_version,site_docroot)";
+    $q .= " VALUES ('" . APP_PREFIX . "', '$AXYL_VERSION','$WWW_PATH')";
+    $res = dbcommand($q);
+    if ($res) logit(" -- done.");
+    else logit( "-- FAILED");
+  }
+}
+
+logit(" ++ ax_user password security update..");
+// Check user table structure..
+$q  = "SELECT pga.attname as fieldname";
+$q .= "  FROM pg_class pgc,pg_attribute pga";
+$q .= " WHERE pgc.relname='ax_user'";
+$q .= "   AND pga.attrelid=pgc.oid";
+$q .= "   AND pga.attname='passwd_history'";
+$chkuser = dbrecordset($q);
+if (!$chkuser->hasdata) {
+  $res = create_new_field("ax_user", "passwd_forever", "bool");
+  if ($res) {
+    dbcommand("ALTER TABLE ax_user ALTER COLUMN passwd_forever SET DEFAULT false");
+    dbcommand("UPDATE ax_user SET passwd_forever=false");
+    dbcommand("ALTER TABLE ax_user ALTER COLUMN passwd_forever SET NOT NULL");
+  }  
+  create_new_field("ax_user", "passwd_expiry", "timestamp with time zone");
+  create_new_field("ax_user", "passwd_history", "text");
+  $res = create_new_field("ax_user", "passwd_failures", "int4");
+  if ($res) {
+    dbcommand("ALTER TABLE ax_user ALTER COLUMN passwd_failures SET DEFAULT 0");
+    dbcommand("UPDATE ax_user SET passwd_failures=0");
+    dbcommand("ALTER TABLE ax_user ALTER COLUMN passwd_failures SET NOT NULL");
+  }
+  $res = create_new_field("ax_user", "locked", "bool");
+  if ($res) {
+    dbcommand("ALTER TABLE ax_user ALTER COLUMN locked SET DEFAULT false");
+    dbcommand("UPDATE ax_user SET locked=false");
+    dbcommand("ALTER TABLE ax_user ALTER COLUMN locked SET NOT NULL");
+  }
+  if ($res) {
+    logit(" -- ax_user password security update was applied.");
+  }
+  else {
+    logit(" -- ERROR: problems applying ax_user password security update.");
+  }
+}
+else {
+  logit(" -- ax_user password security update has already been applied.. good.");
+}
+
+logit(" ++ ax_user user_type assertion..");
+dbcommand("UPDATE ax_user SET user_type='user' WHERE user_type <> 'user' AND user_type <> 'sys'");
+logit(" -- ax_user user_type assertion.. done.");
+
+
+logit(" ++ ax_block 'columns' to 'cols' rename..");
 $q  = "SELECT pga.attname as fieldname";
 $q .= "  FROM pg_class pgc,pg_attribute pga";
 $q .= " WHERE pgc.relname='ax_block'";
 $q .= "   AND pga.attrelid=pgc.oid";
-$q .= "   AND pga.attname='columns'";
+$q .= "   AND pga.attname='cols'";
 $axblock = dbrecordset($q);
 if ($axblock->hasdata) {
-  $res = dbcommand("ALTER TABLE ax_block RENAME COLUMN columns TO cols");
-  if ($res) {
-    logit(" -- successfully renamed axblock.columns --> axblock.cols");
-  }
-  else {
-    logit(" -- ERROR: failed to rename axblock.columns --> axblock.cols");
-  }
+  logit(" -- axblock.cols already present - good");
 }
 else {
   $q  = "SELECT pga.attname as fieldname";
   $q .= "  FROM pg_class pgc,pg_attribute pga";
   $q .= " WHERE pgc.relname='ax_block'";
   $q .= "   AND pga.attrelid=pgc.oid";
-  $q .= "   AND pga.attname='cols'";
+  $q .= "   AND pga.attname='columns'";
   $axblock = dbrecordset($q);
   if ($axblock->hasdata) {
-    logit(" -- axblock.cols already renamed - good");
+    $res = dbcommand("ALTER TABLE ax_block RENAME COLUMN columns TO cols");
+    if ($res) {
+      logit(" -- successfully renamed axblock.columns --> axblock.cols");
+    }
+    else {
+      logit(" -- ERROR: failed to rename axblock.columns --> axblock.cols");
+    }
   }
   else {
     logit(" -- ERROR: neither axblock.cols nor axblock.columns was found!");
   }
 }
-
 $res = create_new_field("ax_block", "blocklet_sep", "INT4");
 if ($res) {
   $res = dbcommand("ALTER TABLE ax_block ALTER COLUMN blocklet_sep SET DEFAULT 0");
@@ -597,11 +729,21 @@ if ($res) {
   }
 }
 
-logit(" -- multi-language extensions");
+logit(" ++ multi-language extensions");
 $q  = "SELECT relname FROM pg_class WHERE relname='ax_language'";
 $langtable = dbrecordset($q);
 if ($langtable->hasdata) {
   logit(" -- ax_language table already present - good");
+  $q  = "SELECT lang_id FROM ax_language WHERE lang_id=0";
+  $deflang = dbrecordset($q);
+  if (!$deflang->hasdata) {
+    logit(" -- creating default language record..");
+    $q  = "INSERT INTO ax_language (lang_id,lang_desc,char_encoding,is_default)";
+    $q .= " VALUES (0,'default','','t')";
+    $res = dbcommand($q);
+    if ($res) logit(" -- done.");
+    else logit( "-- FAILED");
+  }
 }
 else {
   logit(" -- creating ax_language table..");
@@ -649,6 +791,7 @@ if ($res) {
 }
 
 // Make sure we start sessions with a clean slate..
+logit(" ++ menu structure..");
 if ($do_menu_changes) {
   $res = dbcommand("UPDATE ax_wwwsession SET menuoption_id=NULL, menu_status=NULL");
   if ($res) {
@@ -700,7 +843,7 @@ else {
 // ordering which requires them to be iterated a few times..
 $upgrading_schema = true;
 while ($upgrading_schema) {
-  logit("\n -- syncing database '$curdb->name' with Axyl core schema");
+  logit("\n ++ syncing database '$curdb->name' with Axyl core schema");
   logit(" -- using pgdiff to determine upgrade SQL");
   if ($do_menu_changes) {
     logit(" -- NB: re-creating the menu structure. Database diff will notify you");
@@ -925,6 +1068,10 @@ else {
 copy("$AXYL_HOME/www/inc/axyl-template.inc", "./inc/axyl-template.inc");
 copy("$AXYL_HOME/www/inc/cm-formats.inc", "./inc/cm-formats.inc");
 copy("$AXYL_HOME/www/inc/cm-template.inc", "./inc/cm-template.inc");
+copy("$AXYL_HOME/www/inc/microsite-template.inc", "./inc/microsite-template.inc");
+copy("$AXYL_HOME/www/inc/default_template_index.html", "./inc/default_template_index.html");
+copy("$AXYL_HOME/www/inc/default_template_main.html", "./inc/default_template_main.html");
+copy("$AXYL_HOME/www/inc/default_template_popup.html", "./inc/default_template_popup.html");
 logit(" -- copied latest templates to ./inc");
 
 // ----------------------------------------------------------------------
@@ -1111,7 +1258,8 @@ if ($in->opened && $out->opened) {
                   . "\n"
                   . "// -----------------------------------------------------------------------\n"
                   . "// Document root is undefined for command-line scripts..\n"
-                  . "if (!isset(\$DOCUMENT_ROOT)) {\n"
+                  . "\$DOCUMENT_ROOT = \$_SERVER[\"DOCUMENT_ROOT\"];\n"
+                  . "if (empty(\$DOCUMENT_ROOT)) {\n"
                   . "  \$DOCUMENT_ROOT = getcwd();\n"
                   . "}\n"
                   . "// -----------------------------------------------------------------------\n"
@@ -1376,10 +1524,10 @@ if ($bkt->hasdata) {
     // Multimedia objects..
     $datapat = "/(<MEDIA (.*?)>|<IMAGE (.*?)>|<DATA (.*?)>|<DOCUMENT (.*?)>)/i";
     if ( preg_match($datapat, $new_content, $matches) ) {
-      $new_content = preg_replace("/<IMAGE /i", "<object type=\"axyl/embedded-media\" codetype=\"image\" ", $new_content);
-      $new_content = preg_replace("/<MEDIA /i", "<object type=\"axyl/embedded-media\" codetype=\"media\" ", $new_content);
-      $new_content = preg_replace("/<DOCUMENT /i", "<object type=\"axyl/embedded-media\" codetype=\"document\" ", $new_content);
-      $new_content = preg_replace("/<DATA /i", "<object type=\"axyl/embedded-media\" codetype=\"data\" ", $new_content);
+      $new_content = preg_replace("/<IMAGE /i", "<img type=\"axyl/embedded-media\" codetype=\"image\" ", $new_content);
+      $new_content = preg_replace("/<MEDIA /i", "<img type=\"axyl/embedded-media\" codetype=\"media\" ", $new_content);
+      $new_content = preg_replace("/<DOCUMENT /i", "<img type=\"axyl/embedded-media\" codetype=\"document\" ", $new_content);
+      $new_content = preg_replace("/<DATA /i", "<img type=\"axyl/embedded-media\" codetype=\"data\" ", $new_content);
       $new_content = preg_replace("/img_align/i", "align", $new_content);
       $new_content = preg_replace("/img_pad/i", "pad", $new_content);
       $new_content = preg_replace("/mm_width/i", "width", $new_content);
@@ -1455,23 +1603,30 @@ if ($VHSERVERNAMES != "") {
   $VHservernames = explode(" ", $VHSERVERNAMES);
   $VHpaths = array();
   foreach ($VHservernames as $VHservername) {
-    exec("find $APACHE_CONFDIR -type f -exec grep -il \"ServerName $VHservername\" {} \;", $paths);
-    logit(" -- there were ".count($paths)." paths found!");
+    $paths = array();
+    exec("find $APACHE_CONFDIR -type f -exec grep -il \"ServerName $VHservername\" {} \;", $paths1);
+    exec("find $APACHE_CONFDIR -type f -exec grep -il \"ServerAlias $VHservername\" {} \;", $paths2);
+    $paths = array_merge($paths1, $paths2);
+    logit(" -- $VHservername: located in ".count($paths)." paths");
     $vhcnt = 0;
     foreach($paths as $path) {
-      if (!preg_match("/(\.saved)|([-\.]old)|(\.bak)/i", $path)) {
-        $VHpaths[] = $path;
-        logit(" -- examining VH config in: $path");
-        $vhcnt += 1;
+      if (file_exists($path)) {
+        if (!preg_match("/(\.saved)|([-\.]old)|(\.bak)|(.*dpkg.*)/i", $path)) {
+          $VHpaths[$path] = "vh";
+          $vhcnt += 1;
+        }
       }
     }
     if ($vhcnt == 0) {
       logit(" -- no applicable VH configs found.");
     }
+    else {
+      logit(" -- there are " . count($VHpaths) . " unique config files to be processed..");
+    }
   }
   // Directive to insert into Apache VirtualHost config..
   $php_include_path = "php_value include_path \".:$AXYL_HOME/lib:$WWW_PATH\"";
-  foreach ($VHpaths as $VHpath) {
+  foreach ($VHpaths as $VHpath => $dummy) {
     $in = new inputfile($VHpath);
     if ($in->opened) {
       $out = new outputfile($VHpath);
@@ -1522,29 +1677,29 @@ if ($VHSERVERNAMES != "") {
             // Write the virtualhost entry out now..
             foreach ($VHlines as $VHline) {
               if ($VHfound && preg_match("/^[\s]*<\/VirtualHost>/i", $VHline)) {
-                $out->writeln("    $php_include_path");
-                logit(" -- VH re-write: inserting php inlude path");
+                $out->writeln("  $php_include_path");
+                logit(" -- re-write: inserting php inlude path");
                 if (!$hasDir) {
-                  $out->writeln("    <Directory $WWW_PATH>");
-                  $out->writeln("      Order Deny,Allow");
-                  $out->writeln("      Allow from All");
-                  $out->writeln("      Options FollowSymLinks");
-                  $out->writeln("      AllowOverride All");
-                  $out->writeln("    </Directory>");
-                  logit(" -- VH re-write: inserting <Directory> directive");
+                  $out->writeln("  <Directory $WWW_PATH>");
+                  $out->writeln("    Order Deny,Allow");
+                  $out->writeln("    Allow from All");
+                  $out->writeln("    Options FollowSymLinks");
+                  $out->writeln("    AllowOverride All");
+                  $out->writeln("  </Directory>");
+                  logit(" -- re-write: inserting <Directory> directive");
                 }
                 if (!$hasOptSym) {
                   $out->writeln("    Options FollowSymLinks");
-                  logit(" -- VH re-write: inserting Options directive");
+                  logit(" -- re-write: inserting Options directive");
                 }
                 if (!$hasDirIx) {
                   $out->writeln("    DirectoryIndex index.php");
-                  logit(" -- VH re-write: inserting DirectoryIndex directive");
+                  logit(" -- re-write: inserting DirectoryIndex directive");
                 }
                 $do_update = true;
                 copy($VHpath, "$VHpath.axyl-security-update.saved");
-                logit(" -- updated Apache Virtual Host configuration in $VHpath for $currVHservername");
-                logit(" -- backup saved in $VHpath.axyl-security-update.saved");
+                logit(" -- $currVHservername: was re-written");
+                logit(" -- a backup was saved in $VHpath.axyl-security-update.saved");
               }
               // Always output the line if a foreign VH, or if it's our VH and NOT
               // the php_value line, which we will be re-writing above..
@@ -1617,6 +1772,13 @@ if (!file_exists(".htaccess")) {
 }
 logit(" -- done.");
 
+// Axyl website registration..
+$rebuild_script = "$AXYL_HOME/install/rebuild-website-db.sh";
+if (is_executable($rebuild_script)) {
+  logit(" -- re-building the Axyl csv database records..");
+  exec("$rebuild_script >/dev/null 2>&1", $msgs);
+}
+
 // ----------------------------------------------------------------------
 // Do these last messages early, since we have to close the logfile before
 // we remove and replace the Axyl library..
@@ -1653,7 +1815,4 @@ $THISDIR = realpath(".");
 if ($THISDIR != "" && $THISDIR != "/") {
   exec("$AXYL_HOME/install/set-axyl-website-perms.sh");
 }
-?>
-
-
-
+?>
\ No newline at end of file
